cvars <- list("comp_can_but_cant_find_work",
              "comp_can_but_wont_work")

calc_comps <- function(df, cvars) {
  
  df <- df[df$in_post == 1,]
  
  comp_df <- lapply(cvars, function(J){
    var <- J
    df[[J]] <- ifelse(is.na(df[[J]]), "Don't know", df[[J]])
    n_with_dk <- table(df[[J]][df$in_post == 1])
    tot_with_dk <- sum(table(df[[J]][df$in_post == 1]))
    pct_with_dk <- n_with_dk / tot_with_dk
    n_without_dk <- table(df[[J]][df$in_post == 1 & df[[J]]!="Don't know" ])
    tot_without_dk <- sum(table(df[[J]][df$in_post == 1 & df[[J]]!="Don't know" ]))
    pct_without_dk <- n_without_dk / tot_without_dk
    
    out1 <- cbind(var, n_with_dk, tot_with_dk, pct_with_dk, "With DK's")
    colnames(out1) <- c("var", "n", "tot", "pct", "group")
    
    out2 <- cbind(var, n_without_dk, tot_without_dk, pct_without_dk, "Without DK's")
    colnames(out2) <- c("var", "n", "tot", "pct", "group")
    
    out <- rbind(out1, out2)
    return(out)
  })
  comp_df <- as.data.frame(do.call(rbind, comp_df), stringsAsFactors=FALSE)
  comp_df$response <- rownames(comp_df)
  rownames(comp_df) <- NULL
  for(i in 2:4) comp_df[,i] <- as.numeric(comp_df[,i])
  #str(comp_df)
  
  
  return(comp_df)
}

# Overall
pcv_pooled <- calc_comps(df=cces[cces$in_post == 1,], cvars=cvars)

# What percent have a response
1 - pcv_pooled$pct[pcv_pooled$var=="comp_can_but_wont_work" & pcv_pooled$group != "Without DK's" & pcv_pooled$response=="Don't know"]
# What percent don't know
pcv_pooled$pct[pcv_pooled$var=="comp_can_but_wont_work" & pcv_pooled$group != "Without DK's" & pcv_pooled$response=="Don't know"]


# How many think that over 20% of SSDI recipients can but do not want to work
apply(pcv_pooled[pcv_pooled$var=="comp_can_but_wont_work" & pcv_pooled$group == "Without DK's" & pcv_pooled$response!="0-20% (Few)", c("n", "pct")],
      2, sum)

# Median response? (among respondents who don't say DK)
pcv_pooled[pcv_pooled$var=="comp_can_but_wont_work" & pcv_pooled$group == "Without DK's",]
1040/2 # k-th respondent is the median
387+244 # median response is 20-40%


# By party

pcv_dem <- calc_comps(df=cces[cces$rc_pid3=="Democrat",], cvars=cvars)
pcv_ind <- calc_comps(df=cces[cces$rc_pid3=="Independent",], cvars=cvars)
pcv_rep <- calc_comps(df=cces[cces$rc_pid3=="Republican",], cvars=cvars)

# Median response by party

pcv_dem[pcv_dem$var=="comp_can_but_wont_work" & pcv_dem$group == "Without DK's",]
378/2 # k-th respondent is the median; median response is 20-40%

pcv_ind[pcv_ind$var=="comp_can_but_wont_work" & pcv_ind$group == "Without DK's",]
388/2 # k-th respondent is the median
144+90 # median response is 20-40%

pcv_rep[pcv_rep$var=="comp_can_but_wont_work" & pcv_rep$group == "Without DK's",]
274/2  # k-th respondent is the median
56+77 # median response is 40-60%

# Prep results to plot

pcv_dem$pid3 <- "Democrat"
pcv_ind$pid3 <- "Independent"
pcv_rep$pid3 <- "Republican"
pcv_pooled$pid3 <- "Full Sample"

pcv <- rbind(pcv_dem,
             pcv_ind,
             pcv_rep,
             pcv_pooled)


pcv$var_lab <- ifelse(pcv$var == "comp_can_but_cant_find_work",
                      "Perceived Percentage of SSDI Recipients that\nAre Able and Want to Work\nBut Are Unable to Find Suitable Employment",
                      "Perceived Percentage of SSDI Recipients that\nAre In Fact Able to Work\nBut Do Not Want to Work")

pcv$response <- ifelse(pcv$response == "0-20% (Few)", "0-20%\n(Few)", pcv$response)
pcv$response <- ifelse(pcv$response == "80-100% (Most)", "80-100%\n(Most)", pcv$response)
pcv$response <- ifelse(pcv$response == "Don't know", "Don't\nKnow", pcv$response)

pcv$se <- with(pcv, sqrt( (pct * (1-pct))  / n ))

pcv$lci <- with(pcv, pct - qt(0.975,df=n-1)*se) 
pcv$uci <- with(pcv, pct + qt(0.975,df=n-1)*se)

pcv$pid3 <- factor(pcv$pid3, levels = c("Democrat", "Independent", "Republican", "Full Sample"))

#gray4 <- c("#525252","#cccccc","#969696","#f7f7f7")
gray4 <- c("#252525","#969696","#737373","#d9d9d9")

ggplot(pcv[pcv$var == "comp_can_but_wont_work" & 
             pcv$group == "With DK's",], aes(x=response, y=pct, group=pid3, fill=pid3, color=pid3)) + 
  geom_bar(stat="identity", width=.4, position=position_dodge(.5)) +
  #  geom_errorbar(aes(ymin= lci, ymax = uci), width=.1, position=position_dodge(.5)) +
  xlab("\nPerceived Percentage of SSDI Recipients Who Are In Fact Able to Work But Do Not Want to Work") +
  ylab("Proportion of Respondents\n") +
  coord_cartesian(ylim=c(0,.5)) +
  scale_fill_manual(name="Respondent's Party ID", 
                    labels=c("Democrat","Independent","Republican","Full Sample"), 
                    values=gray4) +
  scale_color_manual(name="Respondent's Party ID", 
                     labels=c("Democrat","Independent","Republican","Full Sample"), 
                     values=gray4) +
  theme_bw() + theme(legend.position="bottom") 
#+
#  facet_wrap(~ group, scales="free")
#  facet_grid(group ~ var_lab) 

ggsave("figure1.pdf", height=5, width=9)
