# Pooled - all subjects

# Calculate means
gm <- groupMeans(df=cces[cces$in_pre == 1,],
                 byvars=c("z_diagnosis"), 
                 vars="deserve")
# Plot
ggplot(gm, aes(x=z_diagnosis, y=m)) + 
  geom_point(size=1.5) +
  geom_errorbar(aes(ymin=lci, ymax=uci), width=.1) +
  coord_cartesian(ylim=ylim_range) +
  geom_hline(yintercept=0, lty=2, lwd=1.5, colour="#33333380") +
  xlab("Medical Impairment") + ylab("Agreement with Gov Decision to Grant SSDI Benefits\n(-2=Strongly Disagree, 2=Strongly Agree)") +
  theme_bw() + theme(legend.position="bottom")
ggsave("figure2_panelA.pdf", width=7, height=5)

# By partisanship of subject

# Calculate means
gm <- groupMeans(df=cces[cces$in_pre == 1,],
                 byvars=c("z_diagnosis", "rc_pid3"), 
                 vars="deserve")

gm_line <- gm[gm$rc_pid3 %in% c("Democrat","Republican"), c("z_diagnosis", "m", "rc_pid3")]
gm_line$x_shift <- ifelse(gm_line$rc_pid3 == "Democrat", -.1 , .1 )
gm_line$x_coord <- rep(NA, nrow(gm_line))
gm_line$x_coord <- ifelse(gm_line$z_diagnosis == levels(gm_line$z_diagnosis)[1], 1, gm_line$x_coord)
gm_line$x_coord <- ifelse(gm_line$z_diagnosis == levels(gm_line$z_diagnosis)[2], 2, gm_line$x_coord)
gm_line$x_coord <- ifelse(gm_line$z_diagnosis == levels(gm_line$z_diagnosis)[3], 3, gm_line$x_coord)
gm_line$x_coord <- ifelse(gm_line$z_diagnosis == levels(gm_line$z_diagnosis)[4], 4, gm_line$x_coord)
gm_line$x_coord <- ifelse(gm_line$z_diagnosis == levels(gm_line$z_diagnosis)[5], 5, gm_line$x_coord)

# Plot
ggplot(gm, aes(x=z_diagnosis, y=m, group=rc_pid3, shape=rc_pid3, colour=rc_pid3)) + 
  geom_point(size=3, position=position_dodge(.3)) +
  geom_errorbar(aes(ymin=lci, ymax=uci), width=.15, position=position_dodge(.3)) +
  geom_line(data=gm_line, aes(x=x_coord+x_shift, y=m, group=z_diagnosis), colour="#333333") +
  coord_cartesian(ylim=ylim_range) +
  geom_hline(yintercept=0, lty=2, lwd=1.5, colour="#33333380") +
  scale_colour_manual(name="Subject's Party ID", values=c("blue","gray","red")) + 
  scale_shape_manual(name="Subject's Party ID", values=c(15,16,17)) +
  xlab("Medical Impairment") + ylab("Agreement with Gov Decision to Grant SSDI Benefits\n(-2=Strongly Disagree, 2=Strongly Agree)") +
  theme_bw() + theme(legend.position="bottom")
ggsave("figure2_panelB.pdf", width=7, height=5)