

gm <- lucid19 %>%
  group_by(pid3) %>%
  do(tidy(lm_robust(fh_agree ~ -1 + fh_racediag, data = ., se_type = "classical"))) %>%
  mutate(term = gsub("fh_racediag", "", term, fixed=TRUE),
         treat_race = unlist(lapply(strsplit(term, " + ", fixed=TRUE), function(x) x[1])),
         treat_diag = unlist(lapply(strsplit(term, " + ", fixed=TRUE), function(x) x[2])),
         treat_diag = ifelse(grepl("stroke",treat_diag,fixed=TRUE), "stroke", treat_diag),
         treat_diag = ifelse(grepl("mood",treat_diag,fixed=TRUE), "mood disorder", treat_diag),
         treat_diag = ifelse(grepl("injured",treat_diag,fixed=TRUE), "job injury", treat_diag))

table(gm$treat_diag)

ggplot(gm, aes(x = treat_diag, y = estimate, group = treat_race, color = treat_race, shape = treat_race)) +
  geom_hline(yintercept = 0, lty = 2) +
  geom_point(size = 3, position = position_dodge(.5)) +
  geom_errorbar(aes(ymin = conf.low, ymax = conf.high), width = 0.1, position = position_dodge(.5)) +
  xlab("SSDI Recipient's Diagnosis") +
  ylab("Agrees Recipient Should Receive SSDI\n(-2 strongly disagree - 2 strongly agree)") +
  scale_color_manual(name = "SSDI Recipient's Race", values = gg_color_hue(2), labels = c("African American", "white")) +
  scale_shape_manual(name = "SSDI Recipient's Race", values = c(15, 17), labels = c("African American", "white")) +
  facet_wrap(~ pid3, ncol = 3) +
  theme_bw(base_size = 15) +
  theme(legend.position = "bottom")
ggsave("figure3.pdf", height=5, width=11)

