
with(cces[cces$in_post == 1,], table(att_ssdi_appeal, z_ssdi_rp, exclude=NULL))
with(cces[cces$in_post == 1,], table(att_ssdi_appeal, z_ssdi_rp_lr, exclude=NULL))
with(cces[cces$in_post == 1,], table(att_ssdi_appeal, z_ssdi_co, exclude=NULL))
with(cces[cces$in_post == 1,], table(att_ssdi_appeal, z_ssdi_co_le, exclude=NULL))

cces <- cces %>%
  mutate(exp2_treat = NA,
         exp2_treat = ifelse(!is.na(att_ssdi_appeal) & att_ssdi_appeal == "Select 1 (blank)", "Control", exp2_treat),
         exp2_treat = ifelse(!is.na(att_ssdi_appeal) & att_ssdi_appeal == "Select 2", "Risk Pooling", exp2_treat),
         exp2_treat = ifelse(!is.na(att_ssdi_appeal) & att_ssdi_appeal == "Select 3", "Costly Program", exp2_treat),
         exp2_treat = ifelse(!is.na(att_ssdi_appeal) & att_ssdi_appeal == "Select 4", "Costly Program &\nLax Eligibility", exp2_treat),
         exp2_treat = ifelse(!is.na(att_ssdi_appeal) & att_ssdi_appeal == "Select 5", "Risk Pooling &\nLow Abuse Risk", exp2_treat))

with(cces[cces$in_post == 1,], table(att_ssdi_appeal, exp2_treat, exclude=NULL))
with(cces, table(att_ssdi_appeal, exp2_treat, exclude=NULL))

fig_Ys <- paste0("rc_",Ys)
fig_Ys <- fig_Ys[c(6,2,1,3)]



# Calculate group means

g_means <- cces %>%
  filter(in_post == 1) %>%
  group_by(exp2_treat) %>%
  summarise(n = n(),
            fedgov_mean = mean(rc_att_fedgov_spendtoomuch),
            fedgov_sd = sd(rc_att_fedgov_spendtoomuch),
            fedgov_se = fedgov_sd / sqrt(n),
            fedgov_lci = fedgov_mean - qt(.975, n-1)*fedgov_se,
            fedgov_uci = fedgov_mean + qt(.975, n-1)*fedgov_se,
            canwork_mean = mean(rc_att_ssdi_canwork_majprob),
            canwork_sd = sd(rc_att_ssdi_canwork_majprob),
            canwork_se = canwork_sd / sqrt(n),
            canwork_lci = canwork_mean - qt(.975, n-1)*canwork_se,
            canwork_uci = canwork_mean + qt(.975, n-1)*canwork_se,
            nonsev_mean = mean(rc_att_nonsevere_ineligible),
            nonsev_sd = sd(rc_att_nonsevere_ineligible),
            nonsev_se = nonsev_sd / sqrt(n),
            nonsev_lci = nonsev_mean - qt(.975, n-1)*nonsev_se,
            nonsev_uci = nonsev_mean + qt(.975, n-1)*nonsev_se,
            encwork_mean = mean(rc_att_encourage_work_if_can),
            encwork_sd = sd(rc_att_encourage_work_if_can),
            encwork_se = encwork_sd / sqrt(n),
            encwork_lci = encwork_mean - qt(.975, n-1)*encwork_se,
            encwork_uci = encwork_mean + qt(.975, n-1)*encwork_se)

# reshape
g_means <- gather(g_means, variable, value, -exp2_treat, -n)
g_means$param <- unlist(lapply(strsplit(g_means$variable, "_", fixed=TRUE), function(J) J[2]))
g_means$variable <- unlist(lapply(strsplit(g_means$variable, "_", fixed=TRUE), function(J) J[1]))
g_means <- spread(g_means, param, value)

# create outcome label
g_means <- g_means %>%
  mutate(outcome = NA,
         outcome = ifelse(variable == "canwork", "Major problem if person can work\nbut opts for disability if\nfaces employment challenges", outcome),
         outcome = ifelse(variable == "encwork", "Encourage individual to\nreturn to work if\nimpairment is less severe", outcome),
         outcome = ifelse(variable == "fedgov", "Federal government is\nspending too much\non SSDI benefit payments", outcome),
         outcome = ifelse(variable == "nonsev", "Individuals with\nnon-severe impairments\nshould be ineligible for SSDI", outcome),
         outcome = factor(outcome, levels=c("Federal government is\nspending too much\non SSDI benefit payments",
                                            "Major problem if person can work\nbut opts for disability if\nfaces employment challenges",
                                            "Individuals with\nnon-severe impairments\nshould be ineligible for SSDI",
                                            "Encourage individual to\nreturn to work if\nimpairment is less severe")),
         exp2_treat = factor(exp2_treat, levels=rev(c("Control",
                                                      "Risk Pooling",
                                                      "Risk Pooling &\nLow Abuse Risk",
                                                      "Costly Program",
                                                      "Costly Program &\nLax Eligibility"))))


# plot

ggplot(g_means, aes(x=exp2_treat, y=mean)) +
  geom_hline(yintercept = 0, lty = 2, colour = "gray") +
  geom_point() +
  geom_errorbar(aes(ymin=lci, ymax=uci), width=.2) +
  facet_wrap(~outcome, ncol = 1, strip.position="right") +
  coord_flip(ylim=c(-.5,1.5)) +
  labs(x="Experimental Condition\n", y="\nMean Agreement (-2=strongly disagree; 2=strongly agree)") +
  theme_bw()

ggsave("figure4.pdf", width=6, height=9)