cvars <- list("comp_can_but_cant_find_work",
              "comp_can_but_wont_work")

calc_comps <- function(df, cvars) {
  
  df <- df[df$in_post == 1,]
  
  comp_df <- lapply(cvars, function(J){
    var <- J
    n_with_dk <- table(df[[J]][df$in_post == 1])
    tot_with_dk <- sum(table(df[[J]][df$in_post == 1]))
    pct_with_dk <- n_with_dk / tot_with_dk
    n_without_dk <- table(df[[J]][df$in_post == 1 & df[[J]]!="Don't know" ])
    tot_without_dk <- sum(table(df[[J]][df$in_post == 1 & df[[J]]!="Don't know" ]))
    pct_without_dk <- n_without_dk / tot_without_dk
    
    out1 <- cbind(var, n_with_dk, tot_with_dk, pct_with_dk, "With DK's")
    colnames(out1) <- c("var", "n", "tot", "pct", "group")
    
    out2 <- cbind(var, n_without_dk, tot_without_dk, pct_without_dk, "Without DK's")
    colnames(out2) <- c("var", "n", "tot", "pct", "group")
    
    out <- rbind(out1, out2)
    return(out)
  })
  comp_df <- as.data.frame(do.call(rbind, comp_df), stringsAsFactors=FALSE)
  comp_df$response <- rownames(comp_df)
  rownames(comp_df) <- NULL
  for(i in 2:4) comp_df[,i] <- as.numeric(comp_df[,i])
  #str(comp_df)
  
  
  return(comp_df)
}

pcv_dem <- calc_comps(df=cces[cces$rc_pid3=="Democrat",], cvars=cvars)
pcv_ind <- calc_comps(df=cces[cces$rc_pid3=="Independent",], cvars=cvars)
pcv_rep <- calc_comps(df=cces[cces$rc_pid3=="Republican",], cvars=cvars)

pcv_dem$pid3 <- "Democrat"
pcv_ind$pid3 <- "Independent"
pcv_rep$pid3 <- "Republican"

pcv <- rbind(pcv_dem,
             pcv_ind,
             pcv_rep)

pcv$var_lab <- ifelse(pcv$var == "comp_can_but_cant_find_work",
                      "Perceived Percentage of SSDI Recipients that\nAre Able and Want to Work\nBut Are Unable to Find Suitable Employment",
                      "Perceived Percentage of SSDI Recipients that\nAre In Fact Able to Work\nBut Do Not Want to Work")

pcv$response <- ifelse(pcv$response == "0-20% (Few)", "0-20%\n(Few)", pcv$response)
pcv$response <- ifelse(pcv$response == "80-100% (Most)", "80-100%\n(Most)", pcv$response)
pcv$response <- ifelse(pcv$response == "Don't know", "Don't\nKnow", pcv$response)



ggplot(pcv[pcv$var != "comp_can_but_wont_work" & pcv$group == "With DK's",], aes(x=response, y=pct, group=pid3, fill=pid3)) + 
  geom_bar(stat="identity", width=.4, position=position_dodge(.5)) +
  xlab("\nPerceived Percentage of SSDI Recipients Who Are Able and Want to Work But Are Unable to Find Suitable Employment") +
  ylab("Proportion of Respondents\n") +
  coord_cartesian(ylim=c(0,.5)) +
  scale_colour_manual(name="Respondent's Party ID", labels=c("Democrat","Independent","Republican"), values=c("blue","gray","red")) +
  scale_fill_manual(name="Respondent's Party ID", labels=c("Democrat","Independent","Republican"), values=c("blue","gray","red")) +
  theme_bw() + theme(legend.position="bottom")


ggsave("appendix_figureA1.pdf", height=5, width=9)