## Plot densities by party, policy, trait of beneficiary

dstack <- lucid19 %>%
  dplyr::select(fh_ssdi_blk   , 
         fh_ssdi_wom   , 
         fh_ssdi_usb   ,
         fh_othpol_blk ,
         fh_othpol_wom ,
         fh_othpol_usb ,
         fh_othpol_short,
         pid3,
         ssdi_attn_pass,
         othpol_attn_pass) %>%
  mutate(id = 1:n()) %>%
  gather(variable, value, -id, -pid3, -fh_othpol_short, -ssdi_attn_pass, -othpol_attn_pass) %>%
  mutate(variable = as.character(variable),
         policy = ifelse(grepl("ssdi", variable, fixed=TRUE), "SSDI", fh_othpol_short),
         policy = factor(policy, levels = c("SSDI", "TANF", "Social Security", "Medicaid")),
         attn_pass = ifelse(grepl("ssdi", variable, fixed=TRUE), ssdi_attn_pass, othpol_attn_pass),
         both_pass = as.numeric(ssdi_attn_pass == 1 & othpol_attn_pass == 1),
         rating = unlist(lapply(strsplit(variable, "_", fixed=TRUE), function(x) x[length(x)])),
         popshare = NA,
         popshare = ifelse(rating == "blk", 13, popshare),
         popshare = ifelse(rating == "wom", 51, popshare),
         popshare = ifelse(rating == "usb", 87, popshare),
         rating = ifelse(rating == "blk", "Black/African American", rating),
         rating = ifelse(rating == "usb", "U.S. Born", rating),
         rating = ifelse(rating == "wom", "Women", rating),
         rating = factor(rating, levels = c("Black/African American", "Women", "U.S. Born")),
         pid3 = factor(pid3, levels = c("Rep", "Ind", "Dem")))

## Plot -- restrict sample to those passing attention checks

ggplot(dstack[dstack$both_pass == 1,], aes(x = value, y = pid3, color = pid3, fill = pid3)) +
  geom_vline(aes(xintercept = popshare), data = dstack, lty = 2) +
  geom_density_ridges(na.rm = TRUE) +
  coord_cartesian(xlim = c(0, 100)) +
  scale_color_manual(name = "Subject's Party", values = alpha(c("red", "purple", "blue"), .25), labels = c("Rep", "Ind", "Dem")) +
  scale_fill_manual(name = "Subject's Party", values = alpha(c("red", "purple", "blue"), .25), labels = c("Rep", "Ind", "Dem")) +
  ylab("") +
  xlab("Perceived Percent of Program Beneficiaries with Given Trait") +
  facet_grid(policy ~ rating) +
  theme_ridges(font_size = 14) +
  theme(legend.position = "none")
ggsave("appendix_figureA4.pdf", height=9, width=7)


## Plot -- no sample restriction

ggplot(dstack, aes(x = value, y = pid3, color = pid3, fill = pid3)) +
  geom_vline(aes(xintercept = popshare), data = dstack, lty = 2) +
  geom_density_ridges(na.rm = TRUE) +
  coord_cartesian(xlim = c(0, 100)) +
  scale_color_manual(name = "Subject's Party", values = alpha(c("red", "purple", "blue"), .25), labels = c("Rep", "Ind", "Dem")) +
  scale_fill_manual(name = "Subject's Party", values = alpha(c("red", "purple", "blue"), .25), labels = c("Rep", "Ind", "Dem")) +
  ylab("") +
  xlab("Perceived Percent of Program Beneficiaries with Given Trait") +
  facet_grid(policy ~ rating) +
  theme_ridges(font_size = 14) +
  theme(legend.position = "none")
ggsave("appendix_figureA6.pdf", height=9, width=7)
