
tab_modes <- dstack %>%
  filter(both_pass == 1) %>%
  mutate(pid3 = factor(pid3, levels = c("Dem", "Ind", "Rep"))) %>%
  group_by(pid3, rating, policy) %>%
  summarise(mode = Mode(value))

popshares <- data.frame(rating = c("Black/African American", "Women", "U.S. Born"),
                        level = c(13, 51, 87))

ggplot(tab_modes, aes(x=pid3, y=mode, group=policy)) +
  geom_hline(data = popshares, aes(yintercept = level), lty = 2) +
  geom_point(size=3, alpha = .5) +
  geom_text_repel(aes(label=policy), hjust=0, vjust=0) +
  scale_y_continuous(breaks = seq(0,100,10), labels = seq(0,100,10)) +
  ylab("Modal Response (Percent of Program Beneficiaries with Trait)") +
  xlab("Respondent's Party Identification") +
  facet_wrap( ~ rating) +
  theme_bw(base_size = 15) +
  theme(legend.position = "none")

ggsave("appendix_figureA5.pdf", height=6, width=11)
