
ate_race <- lucid19 %>%
  do(tidy(lm_robust(fh_agree ~ fh_race, data = ., se_type = "classical"))) %>%
  mutate(term = gsub("fh_race", "", term, fixed=TRUE),
         analysis = "Recipient Race Effect\n(comparison group: beneficiary is white)")

ate_diag <- lucid19 %>%
  do(tidy(lm_robust(fh_agree ~ fh_diagnosis, data = ., se_type = "classical"))) %>%
  mutate(term = gsub("fh_diagnosis", "", term, fixed=TRUE),
         analysis = "Recipient Diagnosis Effects\n(comparison group: injured on job)")

ate <- bind_rows(ate_race, ate_diag)

ggplot(ate[ate$term != "(Intercept)",], aes(x = term, y = estimate)) +
  geom_hline(yintercept = 0, lty = 2) +
  geom_point(size = 3) +
  geom_errorbar(aes(ymin = conf.low, ymax = conf.high), width = 0.1) +
  xlab("Treatment") +
  ylab("Average Treatment Effect on Agreeing\nRecipient Should Receive SSDI") +
  facet_wrap(~ analysis, ncol = 2, scales = "free") +
  theme_bw(base_size = 15) +
  theme(legend.position = "bottom")

ggsave("appendix_figureA7.pdf", height=5, width=9)
