library(nnet)

# Randomization check: Experiment 1

d_exp1 <- cces[cces$in_pre == 1,]
mnl_fit = multinom(z_diagnosis ~ age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat, 
                   data=d_exp1, trace=FALSE) # trace=FALSE to suppress output about convergence
kparams = length(mnl_fit$coefnames)
mnl_loglik = -(mnl_fit$AIC - 2*kparams)/2   # log likelihood from actual model

# randomization inference
niter = 1000

set.seed(20171103)
mnl_loglik_ri <- sapply(1:niter, function(J){
  cat(J, " ... ")
  d_exp1$z_ri <- d_exp1$z_diagnosis[sample(1:nrow(d_exp1), nrow(d_exp1), replace=FALSE)]
  mnl_fit_ri = multinom(z_ri ~ age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat, 
                        data=d_exp1, trace=FALSE) # trace=FALSE to suppress output about convergence
  kparams = length(mnl_fit_ri$coefnames)
  llri = -(mnl_fit_ri$AIC - 2*kparams)/2
  return(llri)
})

# calculate p-value
mean(abs(mnl_loglik_ri) >= abs(mnl_loglik))
# [1] 0.382

# Randomization check: Experiment 2

d_exp2 <- cces[cces$in_post == 1,]
mnl_fit = multinom(z_ssdi_appeal ~ age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat, 
                   data=d_exp2, trace=FALSE) # trace=FALSE to suppress output about convergence
kparams = length(mnl_fit$coefnames)
mnl_loglik = -(mnl_fit$AIC - 2*kparams)/2   # log likelihood from actual model

# randomization inference
niter = 1000

set.seed(20171103)
mnl_loglik_ri <- sapply(1:niter, function(J){
  d_exp2$z_ri <- d_exp2$z_ssdi_appeal[sample(1:nrow(d_exp2), nrow(d_exp2), replace=FALSE)]
  mnl_fit_ri = multinom(z_ri ~ age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat, 
                        data=d_exp2, trace=FALSE) # trace=FALSE to suppress output about convergence
  kparams = length(mnl_fit_ri$coefnames)
  llri = -(mnl_fit_ri$AIC - 2*kparams)/2
  return(llri)
})

# calculate p-value
mean(abs(mnl_loglik_ri) >= abs(mnl_loglik))
# [1] 0.265