freq_hh <- with(cces[cces$in_pre == 1,], table(receive_ssdi_household, exclude=NULL))
freq_fr <- with(cces[cces$in_pre == 1,], table(receive_ssdi_friends, exclude=NULL))
freq_xf <- with(cces[cces$in_pre == 1,], table(receive_ssdi_extfam, exclude=NULL))
freq_co <- with(cces[cces$in_pre == 1,], table(receive_ssdi_community, exclude=NULL))

n_pre <- sum(cces$group %in% c("Group A", "Group C"))
n_post <- sum(table(cces$YAL_group[!is.na(cces$YAL_group)]))

prop_hh <- freq_hh / n_pre * 100
prop_fr <- freq_fr / n_pre * 100
prop_xf <- freq_xf / n_pre * 100
prop_co <- freq_co / n_pre * 100

ratio_others <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  round(J[2]/J[3], 2)
})
ratio_others <- unlist(ratio_others)
names(ratio_others) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")

ratio_others <- c("", ratio_others[1],
                  "", ratio_others[2], 
                  "", ratio_others[3], 
                  "", ratio_others[4])

oth_ssdi <- cbind(as.character(c(freq_hh, sum(freq_hh))), round(c(prop_hh, sum(prop_hh)), 2),
                  c(freq_xf, sum(freq_xf)), round(c(prop_xf, sum(prop_xf)),2),
                  c(freq_fr, sum(freq_fr)), round(c(prop_fr, sum(prop_fr)),2),
                  c(freq_co, sum(freq_co)), round(c(prop_co, sum(prop_co)),2))

rownames(oth_ssdi) <- c("(1) No", 
                        "(2) Yes and legitimately received", 
                        "(3) Yes but could have worked",
                        "(4) Yes but DK if could work",
                        "(5) Don't Know/Refused",
                        "(6) Total")

colnames(oth_ssdi) <- c("In HH, N", "%",
                        "In Ext Fam, N", "%",
                        "Among Friends, N", "%",
                        "In Comm, N", "%")

oth_ssdi <- rbind(oth_ssdi,
                  rep("", 8),
                  rep("", 8),
                  rep("", 8),
                  ratio_others)

rownames(oth_ssdi)[nrow(oth_ssdi)-1] <- "Ratio of Legitimately Received (Panel A, Row 2)"
rownames(oth_ssdi)[nrow(oth_ssdi)] <- " to Could Have Worked (Panel A, Row 3)"
oth_ssdi

sgout <- stargazer(oth_ssdi, column.sep.width = "0pt", float = FALSE)
sgout

swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}} ccccccccc} ", "\\begin{tabular}{@{\\extracolsep{0pt}} lrrrrrrrr} "),
                     c(" & In HH, N & \\% & In Ext Fam, N & \\%.1 & Among Friends, N & \\%.2 & In Comm, N & \\%.3 \\\\ ",
                       "Knowledge of Other SSDI Benefit Recipients in Group & N & \\% & N & \\% & N & \\% & N & \\% \\\\ "))

oth_ssdi <- makeTexTable(sgout=sgout,
                         caption="Reported Knowledge of Other SSDI Benefit Recipients, by Social Reference Group",
                         label="tab:ssdi_oth_all",
                         rsboxwidth = 1,
                         notes = c("Source: 2016 CCES team module, pre-election wave", 
                                   "Cells contain frequencies and percentages. Percentages may not sum to 100 due to rounding."),
                         swaps = swaps_input)

oth_ssdi <- c(oth_ssdi[1:12], 
              " &  &  &  &  &  &  &  & \\\\",
              " \\multicolumn{9}{c}{\\textbf{A. Distribution by social reference group and }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ by belief about the legitimacy of others' benefit receipt}} \\\\",
              " &  &  &  &  &  &  &  & \\\\",
              "& \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{In Extended} & \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{} \\\\",
              "& \\multicolumn{2}{c}{In Household} & \\multicolumn{2}{c}{Family} & \\multicolumn{2}{c}{Among Friends} & \\multicolumn{2}{c}{In Community} \\\\",
              "\\cline{2-9}",
              oth_ssdi[13:19],
              "\\hline",
              oth_ssdi[20:21],
              "\\hline",
              " &  &  &  &  &  &  &  & \\\\",
              " \\multicolumn{9}{c}{\\textbf{B. Ratio of perceiving other SSDI recipients as  }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ legitimate beneficiaries to perceiving other SSDI recipients as }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ illegitimate beneficiaries (i.e., they could have worked) }} \\\\",
              " &  &  &  &  &  &  &  & \\\\",
              "& \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{In Extended} & \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{} \\\\",
              "& \\multicolumn{2}{c}{In Household} & \\multicolumn{2}{c}{Family} & \\multicolumn{2}{c}{Among Friends} & \\multicolumn{2}{c}{In Community} \\\\",
              "\\cline{2-9}",
              oth_ssdi[23:24],
              "\\hline",
              oth_ssdi[25:length(oth_ssdi)])

cat(oth_ssdi, file="table1_panel1.tex", sep="\n")


# Robustness of ratios to including rows 4 and to including rows 4 and 5 in denominator

# rows 3+4 in denominator
ratio_others_robust1 <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  round(J[2]/(J[3]+J[4]), 2)
})
ratio_others_robust1 <- unlist(ratio_others_robust1)
names(ratio_others_robust1) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")
ratio_others_robust1

# rows 3+4+5 in denominator
ratio_others_robust2 <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  round(J[2]/(J[3]+J[4]+J[5]), 2)
})
ratio_others_robust2 <- unlist(ratio_others_robust2)
names(ratio_others_robust2) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")
ratio_others_robust2