with(cces[cces$in_pre == 1,], table(receive_ssdi_household, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_friends, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_extfam, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_community, exclude=NULL))


# Create flags - if anyone receives within network
cces$any_receive_ssdi_hh <- ifelse(cces$in_pre == 1, 0, NA)
cces$any_receive_ssdi_hh <- ifelse(cces$in_pre == 1 & grepl("Yes", cces$receive_ssdi_household, fixed=TRUE),
                                1, cces$any_receive_ssdi_hh)


cces$any_receive_ssdi_fr <- ifelse(cces$in_pre == 1, 0, NA)
cces$any_receive_ssdi_fr <- ifelse(cces$in_pre == 1 & grepl("Yes", cces$receive_ssdi_friends, fixed=TRUE),
                                1, cces$any_receive_ssdi_fr)

cces$any_receive_ssdi_ex <- ifelse(cces$in_pre == 1, 0, NA)
cces$any_receive_ssdi_ex <- ifelse(cces$in_pre == 1 & grepl("Yes", cces$receive_ssdi_extfam, fixed=TRUE),
                                1, cces$any_receive_ssdi_ex)

cces$any_receive_ssdi_co <- ifelse(cces$in_pre == 1, 0, NA)
cces$any_receive_ssdi_co <- ifelse(cces$in_pre == 1 & grepl("Yes", cces$receive_ssdi_community, fixed=TRUE),
                                1, cces$any_receive_ssdi_co)

# Check flags

with(cces[cces$in_pre == 1,], table(receive_ssdi_household, any_receive_ssdi_hh, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_friends, any_receive_ssdi_fr, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_extfam, any_receive_ssdi_ex, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_community, any_receive_ssdi_co, exclude=NULL))

# Create flag: If knowing someone in HH and knowing anyone outside HH (variable: any_ssdi_hh_oth)

cces$any_ssdi_outside_hh_sum <- apply(cces[,c("any_receive_ssdi_fr",
                                        "any_receive_ssdi_ex",
                                        "any_receive_ssdi_co")],
                                   1,
                                   function(x) sum(x, na.rm=TRUE))

cces[,c("any_ssdi_outside_hh_sum", "any_receive_ssdi_fr", "any_receive_ssdi_ex", "any_receive_ssdi_co")]

cces$any_ssdi_hh_oth <- ifelse(cces$in_pre == 1, 
                            as.numeric(cces$any_receive_ssdi_hh == 1 & cces$any_ssdi_outside_hh_sum > 0),
                            NA)

with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,], table(any_receive_ssdi_hh, any_ssdi_hh_oth, exclude=NULL))
with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 0,], table(any_receive_ssdi_hh, any_ssdi_hh_oth, exclude=NULL))

# Describe overall nature of beliefs about deservingness
# Calculate weighted average of deservingness

# two-category (1=undeserving, 0=otherwise)
cces$pcv_undeserve_hh <- as.numeric(grepl("they probably could have worked", cces$receive_ssdi_household, fixed=TRUE))
cces$pcv_undeserve_fr <- as.numeric(grepl("they probably could have worked", cces$receive_ssdi_friends, fixed=TRUE))
cces$pcv_undeserve_ex <- as.numeric(grepl("they probably could have worked", cces$receive_ssdi_extfam, fixed=TRUE))
cces$pcv_undeserve_co <- as.numeric(grepl("they probably could have worked", cces$receive_ssdi_community, fixed=TRUE))

cces$pcv_undeserve_hh <- ifelse(cces$receive_ssdi_household == "No" | is.na(cces$receive_ssdi_household), NA, cces$pcv_undeserve_hh)
cces$pcv_undeserve_fr <- ifelse(cces$receive_ssdi_friends == "No" | is.na(cces$receive_ssdi_friends), NA, cces$pcv_undeserve_fr)
cces$pcv_undeserve_ex <- ifelse(cces$receive_ssdi_extfam == "No" | is.na(cces$receive_ssdi_extfam), NA, cces$pcv_undeserve_ex)
cces$pcv_undeserve_co <- ifelse(cces$receive_ssdi_community == "No" | is.na(cces$receive_ssdi_community), NA, cces$pcv_undeserve_co)

with(cces[cces$in_pre == 1,], table(receive_ssdi_household, pcv_undeserve_hh, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_friends, pcv_undeserve_fr, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_extfam, pcv_undeserve_ex, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_community, pcv_undeserve_co, exclude=NULL))

cces$undeserve_num <- apply(cces[, c("pcv_undeserve_hh", "pcv_undeserve_fr", "pcv_undeserve_ex", "pcv_undeserve_co")],
                         1, function(x) mean(x, na.rm=TRUE))

cces$undeserve_num <- ifelse(cces$in_pre == 0, NA, cces$undeserve_num)
table(cces$undeserve_num, exclude=NULL)
mean(cces$undeserve_num, na.rm=TRUE)

# three-category (1=undeserving, 0.5=dk/otherwise, 0=deserving)

cces$pcv_undeserve_hh_3cat <- ifelse(grepl("they probably could have worked", cces$receive_ssdi_household, fixed=TRUE), 1,
                                  ifelse(grepl("legitimately received", cces$receive_ssdi_household, fixed=TRUE), 0, 0.5))
cces$pcv_undeserve_fr_3cat <- ifelse(grepl("they probably could have worked", cces$receive_ssdi_friends, fixed=TRUE), 1,
                                  ifelse(grepl("legitimately received", cces$receive_ssdi_friends, fixed=TRUE), 0, 0.5))
cces$pcv_undeserve_ex_3cat <- ifelse(grepl("they probably could have worked", cces$receive_ssdi_extfam, fixed=TRUE), 1,
                                  ifelse(grepl("legitimately received", cces$receive_ssdi_extfam, fixed=TRUE), 0, 0.5))
cces$pcv_undeserve_co_3cat <- ifelse(grepl("they probably could have worked", cces$receive_ssdi_community, fixed=TRUE), 1,
                                  ifelse(grepl("legitimately received", cces$receive_ssdi_community, fixed=TRUE), 0, 0.5))

cces$pcv_undeserve_hh_3cat <- ifelse(cces$receive_ssdi_household == "No" | is.na(cces$receive_ssdi_household), NA, cces$pcv_undeserve_hh_3cat)
cces$pcv_undeserve_fr_3cat <- ifelse(cces$receive_ssdi_friends == "No" | is.na(cces$receive_ssdi_friends), NA, cces$pcv_undeserve_fr_3cat)
cces$pcv_undeserve_ex_3cat <- ifelse(cces$receive_ssdi_extfam == "No" | is.na(cces$receive_ssdi_extfam), NA, cces$pcv_undeserve_ex_3cat)
cces$pcv_undeserve_co_3cat <- ifelse(cces$receive_ssdi_community == "No" | is.na(cces$receive_ssdi_community), NA, cces$pcv_undeserve_co_3cat)

with(cces[cces$in_pre == 1,], table(receive_ssdi_household, pcv_undeserve_hh_3cat, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_friends, pcv_undeserve_fr_3cat, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_extfam, pcv_undeserve_ex_3cat, exclude=NULL))
with(cces[cces$in_pre == 1,], table(receive_ssdi_community, pcv_undeserve_co_3cat, exclude=NULL))

cces$undeserve_num_3cat <- apply(cces[, c("pcv_undeserve_hh_3cat", "pcv_undeserve_fr_3cat", 
                                    "pcv_undeserve_ex_3cat", "pcv_undeserve_co_3cat")],
                              1, function(x) mean(x, na.rm=TRUE))
cces$undeserve_num_3cat <- ifelse(cces$in_pre == 0, NA, cces$undeserve_num_3cat)
table(cces$undeserve_num_3cat, exclude=NULL)

mean(cces$undeserve_num_3cat, na.rm=TRUE)

#------------------------------------------------------------------------------------------#

# Calculate ratios conditional on knowing someone in HH receiving SSDI and knowing anyone outside of HH receiving SSDI

n_pre_hh_oth <- nrow(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,])

freq_hh <- with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,], table(receive_ssdi_household, exclude=NULL))
freq_fr <- with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,], table(receive_ssdi_friends, exclude=NULL))
freq_xf <- with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,], table(receive_ssdi_extfam, exclude=NULL))
freq_co <- with(cces[cces$in_pre == 1 & cces$any_ssdi_hh_oth == 1,], table(receive_ssdi_community, exclude=NULL))

freq_hh <- c(0, freq_hh)
names(freq_hh)[1] <- "No"

length(freq_hh)
length(freq_fr)
length(freq_xf)
length(freq_co)

prop_hh <- freq_hh / n_pre_hh_oth * 100
prop_fr <- freq_fr / n_pre_hh_oth * 100
prop_xf <- freq_xf / n_pre_hh_oth * 100
prop_co <- freq_co / n_pre_hh_oth * 100

ratio_others <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  sprintf("%.2f", round(J[2]/J[3], 2))
})
ratio_others <- unlist(ratio_others)
names(ratio_others) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")

ratio_others <- c("", ratio_others[1],
                  "", ratio_others[2], 
                  "", ratio_others[3], 
                  "", ratio_others[4])

oth_ssdi <- cbind(as.character(c(freq_hh, sum(freq_hh))), sprintf("%.2f", round(c(prop_hh, sum(prop_hh)), 2)),
                  c(freq_xf, sum(freq_xf)), sprintf("%.2f", round(c(prop_xf, sum(prop_xf)),2)),
                  c(freq_fr, sum(freq_fr)), sprintf("%.2f", round(c(prop_fr, sum(prop_fr)),2)),
                  c(freq_co, sum(freq_co)), sprintf("%.2f", round(c(prop_co, sum(prop_co)),2)))

rownames(oth_ssdi) <- c("(1) No", 
                        "(2) Yes and legitimately received", 
                        "(3) Yes but could have worked",
                        "(4) Yes but DK if could work",
                        "(5) Don't Know/Refused",
                        "(6) Total")

colnames(oth_ssdi) <- c("In HH, N", "%",
                        "In Ext Fam, N", "%",
                        "Among Friends, N", "%",
                        "In Comm, N", "%")

oth_ssdi <- rbind(oth_ssdi,
                  rep("", 8),
                  rep("", 8),
                  rep("", 8),
                  ratio_others)

rownames(oth_ssdi)[nrow(oth_ssdi)-1] <- "Ratio of Legitimately Received (Panel A, Row 2)"
rownames(oth_ssdi)[nrow(oth_ssdi)] <- " to Could Have Worked (Panel A, Row 3)"
oth_ssdi

sgout <- stargazer(oth_ssdi, column.sep.width = "0pt", float = FALSE)
sgout

swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}} ccccccccc} ", "\\begin{tabular}{@{\\extracolsep{0pt}} lrrrrrrrr} "),
                     c(" & In HH, N & \\% & In Ext Fam, N & \\%.1 & Among Friends, N & \\%.2 & In Comm, N & \\%.3 \\\\ ",
                       "Knowledge of Other SSDI Benefit Recipients in Group & N & \\% & N & \\% & N & \\% & N & \\% \\\\ "))

oth_ssdi <- makeTexTable(sgout=sgout,
                         caption="Reported Knowledge of Other SSDI Benefit Recipients, by Social Reference Group (among Respondents Knowing Someone In Own Household and Anyone Outside of Household Receiving SSDI)",
                         label="tab:ssdi_oth_inandouthh",
                         rsboxwidth = 1,
                         notes = c("Source: 2016 CCES team module, pre-election wave", 
                                   "Cells contain frequencies and percentages. Percentages may not sum to 100 due to rounding."),
                         swaps = swaps_input)

oth_ssdi <- c(oth_ssdi[1:12], 
              " &  &  &  &  &  &  &  & \\\\",
              " \\multicolumn{9}{c}{\\textbf{A. Distribution by social reference group and }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ by belief about the legitimacy of others' benefit receipt}} \\\\",
              " &  &  &  &  &  &  &  & \\\\",
              "& \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{In Extended} & \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{} \\\\",
              "& \\multicolumn{2}{c}{In Household} & \\multicolumn{2}{c}{Family} & \\multicolumn{2}{c}{Among Friends} & \\multicolumn{2}{c}{In Community} \\\\",
              "\\cline{2-9}",
              oth_ssdi[13:19],
              "\\hline",
              oth_ssdi[20:21],
              "\\hline",
              " &  &  &  &  &  &  &  & \\\\",
              " \\multicolumn{9}{c}{\\textbf{B. Ratio of perceiving other SSDI recipients as  }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ legitimate beneficiaries to perceiving other SSDI recipients as }} \\\\",
              " \\multicolumn{9}{c}{\\textbf{ illegitimate beneficiaries (i.e., they could have worked) }} \\\\",
              " &  &  &  &  &  &  &  & \\\\",
              "& \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{In Extended} & \\multicolumn{2}{c}{ } & \\multicolumn{2}{c}{} \\\\",
              "& \\multicolumn{2}{c}{In Household} & \\multicolumn{2}{c}{Family} & \\multicolumn{2}{c}{Among Friends} & \\multicolumn{2}{c}{In Community} \\\\",
              "\\cline{2-9}",
              oth_ssdi[23:24],
              "\\hline",
              oth_ssdi[25:length(oth_ssdi)])

cat(oth_ssdi, file="table1_panel2.tex", sep="\n")


# Robustness of ratios to including rows 4 and to including rows 4 and 5 in denominator

# rows 3+4 in denominator
ratio_others_robust1 <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  round(J[2]/(J[3]+J[4]), 2)
})
ratio_others_robust1 <- unlist(ratio_others_robust1)
names(ratio_others_robust1) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")
ratio_others_robust1

# rows 3+4+5 in denominator
ratio_others_robust2 <- lapply(list(freq_hh, freq_xf, freq_fr, freq_co), function(J) {
  round(J[2]/(J[3]+J[4]+J[5]), 2)
})
ratio_others_robust2 <- unlist(ratio_others_robust2)
names(ratio_others_robust2) <- c("In HH", "In Ext Fam", "Among Friends", "In Comm")
ratio_others_robust2

