
fit1 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1))

fit6 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & rc_ideo3 == "1:Liberal"))
fit7 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & rc_ideo3 == "2:Moderate/DK"))
fit8 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & rc_ideo3 == "3:Conservative"))

sgout <- stargazer(fit1, fit6, fit7, fit8,
                   title="Mean Agreement Score by Treatment Arm (-2=Strongly Disagree, 2=Strongly Agree): Agrees the government should grant SSDI benefits to hypothetical recipient with given medical impairment", 
                   covariate.labels=c("Injured on the job", "Intellectual disability due to stroke", "Mood disorder", "Chronic heart failure", "Severe arthritis of the spine"),
                   column.labels=c("All Subjects", "Liberal", "Moderate", "Conservative"),
                   column.sep.width = "0pt",
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   float=FALSE)

swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}}lcccc} ", "\\begin{tabular}{@{\\extracolsep{0pt}}p{5in}cccc} "),
                     c("\\textit{Note:}  & \\multicolumn{4}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", "")
)

mean_agree_tab2 <- makeTexTable(sgout=sgout,
                                caption="Mean agreement with government decision to grant SSDI benefits to recipient, by the medical impairment of the SSDI benefit recipient and by the subject's ideology.",
                                label="tab:mean_agree_byideo",
                                rsboxwidth = 1,
                                notes = c("Source: 2016 CCES team module, pre-election wave",
                                          "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                          "The outcome variable is the subject's agreement with the government's decision to grant SSDI benefits to a hypothetical recipient with a given medical impairment, and is measured using a 5-point scale (-2=Strongly Disagree, 2=Strongly Agree). The table reports coefficients from an ordinary least squares model regressing the agreement score on binary treatment indicators and no intercept. Standard errors are shown in parentheses."),
                                swaps = swaps_input)

mean_agree_tab2 <- c(mean_agree_tab2[1:12],
                     "& & \\multicolumn{3}{c}{By Subject's Ideology} \\\\",
                     "\\cline{3-5}",
                     mean_agree_tab2[13:length(mean_agree_tab2)])

cat(mean_agree_tab2, file="appendix_tableA10.tex", sep="\n")
