cces$dem <- as.numeric(cces$rc_pid3 == "Democrat")
cces$ind <- as.numeric(cces$rc_pid3 == "Independent")
cces$gop <- as.numeric(cces$rc_pid3 == "Republican")

table(cces$z_diagnosis)

cces$z_any_easier_to_diagnose <- as.numeric(cces$z_diagnosis != "mood\ndisorder")
with(cces, table(z_diagnosis, z_any_easier_to_diagnose, exclude=NULL))
with(cces[cces$in_pre == 1,], table(z_diagnosis, z_any_easier_to_diagnose, exclude=NULL))

fit_hfx_pid <- lm(deserve ~ z_injuredjob + z_stroke + z_heartfail + z_arthritis +
                    dem + ind + 
                    z_injuredjob:dem + z_stroke:dem + z_heartfail:dem + z_arthritis:dem +
                    z_injuredjob:ind + z_stroke:ind + z_heartfail:ind + z_arthritis:ind,
                  data=cces, subset=(in_pre == 1))
summary(fit_hfx_pid)

fit_hfx_pid_pooled <- lm(deserve ~ z_any_easier_to_diagnose +
                           dem + ind + 
                           z_any_easier_to_diagnose:dem + z_any_easier_to_diagnose:ind,
                         data=cces, subset=(in_pre == 1))
summary(fit_hfx_pid_pooled)


sgout <- stargazer(fit_hfx_pid, fit_hfx_pid_pooled,
                   title="Heterogeneous impairment effects by partisanship", 
                   column.labels=c(""),
                   column.sep.width = "0pt",
                   covariate.labels = c("Injured on job", "Stroke-induced intellectual disability", "Chronic heart failure", "Severe arthritis of the spine",
                                        "Any easier-to-diagnose impairment",
                                        "Democrat", "Independent", 
                                        "Injured on job * Democrat", "Stroke * Democrat", "Chronic heart failure * Democrat", "Arthritis * Democrat",
                                        "Injured on job * Independent", "Stroke * Independent", "Chronic heart failure * Independent", "Arthritis * Independent",
                                        "Any easier-to-diagnose impairment * Democrat",
                                        "Any easier-to-diagnose impairment * Independent",
                                        "Constant"),
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   float=FALSE)



swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}}lcc} ", "\\begin{tabular}{@{\\extracolsep{0pt}}p{9in}cc} "),
                     c("\\textit{Note:}  & \\multicolumn{2}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", ""))


impairfxtab_pid <- makeTexTable(sgout=sgout,
                                caption="Heterogeneous effects, by subject partisanship, of alternative easier-to-diagnose impairments (as compared to having a mood disorder, a harder-to-diagnose impairment) on agreement with government decision to grant SSDI benefits to recipient with a given impairment.",
                                label="tab:impairmentfxpid",
                                rsboxwidth = 1,
                                notes = c("Source: 2016 CCES team module, pre-election wave",
                                          "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                          "The outcome variable is the subject's agreement with the government's decision to grant SSDI benefits to a hypothetical recipient with a given medical impairment, and is measured using a 5-point scale (-2=Strongly Disagree, 2=Strongly Agree). The table reports coefficients from an ordinary least squares model regressing the agreement score on binary treatment indicators (omitting the mood disorder condition as the reference group), party identification dummy variables (omitting Republicans as the reference group), and treatment by party interactions. Standard errors are shown in parentheses."),
                                swaps = swaps_input)

cat(impairfxtab_pid, file="appendix_tableA11.tex", sep="\n")

