with(cces, table(in_pre, in_post, exclude=NULL))

# Estimate treatment effects
fit_att <- list()
c_means <- list()
ctr <- 0
for(i in 1:length(Ys)){
  
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le")
  fit_att[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
}
c_means <- sprintf("%.3f", unlist(c_means))


# Robustness: Among those those in both pre and post wave

fit_att_bw <- list()
c_means_bw <- list()
ctr <- 0

for(i in 1:length(Ys)){
  
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le")
  fit_att_bw[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1))
  c_means_bw[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att_bw[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1))
  c_means_bw[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
}
c_means_bw <- sprintf("%.3f", unlist(c_means_bw))




# Robustness: Among those who have never previously received SSDI benefits (among those in both pre and post wave)

fit_att_selfn <- list()
c_means_selfn <- list()
ctr <- 0

for(i in 1:length(Ys)){
  
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le")
  fit_att_selfn[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1 & self_ssdi == "Has never received SSDI"))
  c_means_selfn[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$self_ssdi == "Has never received SSDI" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att_selfn[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1 & self_ssdi == "Has never received SSDI"))
  c_means_selfn[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$self_ssdi == "Has never received SSDI" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
}
c_means_selfn <- sprintf("%.3f", unlist(c_means_selfn))

# Format and export results

sgout <- stargazer(fit_att[[11]], fit_att[[12]], 
                   fit_att[[3]], fit_att[[4]], 
                   fit_att[[1]], fit_att[[2]], 
                   fit_att[[5]], fit_att[[6]],
                   keep = c("z_ssdi_rp", "z_ssdi_rp_lr", "z_ssdi_co", "z_ssdi_co_le", "Constant"),
                   covariate.labels = c("Risk Pooling",
                                        "Risk Pooling + Low Abuse Risk",
                                        "Costly Program",
                                        "Costly Program + Lax Eligibility",
                                        "Constant"),
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   column.sep.width = "0pt",
                   add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                    c("Control Group Mean Outcome", c_means[c(11,12,3,4,1,2,5,6)])),
                   float=FALSE)


sg_bw <- stargazer(fit_att_bw[[11]], fit_att_bw[[12]], 
                   fit_att_bw[[3]], fit_att_bw[[4]], 
                   fit_att_bw[[1]], fit_att_bw[[2]], 
                   fit_att_bw[[5]], fit_att_bw[[6]],
                   keep = c("z_ssdi_rp", "z_ssdi_rp_lr", "z_ssdi_co", "z_ssdi_co_le", "Constant"),
                   covariate.labels = c("Risk Pooling",
                                        "Risk Pooling + Low Abuse Risk",
                                        "Costly Program",
                                        "Costly Program + Lax Eligibility",
                                        "Constant"),
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   column.sep.width = "0pt",
                   add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                    c("Control Group Mean Outcome", c_means_bw[c(11,12,3,4,1,2,5,6)])),
                   float=FALSE)

sg_selfn <- stargazer(fit_att_selfn[[11]], fit_att_selfn[[12]], 
                      fit_att_selfn[[3]], fit_att_selfn[[4]], 
                      fit_att_selfn[[1]], fit_att_selfn[[2]], 
                      fit_att_selfn[[5]], fit_att_selfn[[6]],
                      keep = c("z_ssdi_rp", "z_ssdi_rp_lr", "z_ssdi_co", "z_ssdi_co_le", "Constant"),
                      covariate.labels = c("Risk Pooling",
                                           "Risk Pooling + Low Abuse Risk",
                                           "Costly Program",
                                           "Costly Program + Lax Eligibility",
                                           "Constant"),
                      keep.stat=c("n", "adj.rsq"),
                      dep.var.caption = "",
                      dep.var.labels.include = FALSE,
                      table.placement = "!ht",
                      column.sep.width = "0pt",
                      add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                       c("Control Group Mean Outcome", c_means_selfn[c(11,12,3,4,1,2,5,6)])),
                      float=FALSE)





# Output results as table

swaps_input <- as.matrix(t(c("\\textit{Note:}  & \\multicolumn{8}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", "")),
                         ncol=2, byrow=TRUE)

att_out <- makeTexTable(sgout=sgout,
                        caption="Effect of informational appeals about the SSDI program on SSDI program attitudes",
                        label="tab:attitudes_experiment",
                        rsboxwidth = .85,
                        notes = c("Source: 2016 CCES team module",
                                  "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                  "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, party identification, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                        swaps = swaps_input)

att_out <- c(att_out[1:12],
             "& \\multicolumn{8}{c}{DV = Agreement with statement } \\\\",
             "& \\multicolumn{8}{c}{(5-pt scale, -2 strongly disagree to 2 strongly agree) } \\\\",
             "\\cline{2-9}",
             "& \\multicolumn{2}{c}{Federal gov} & \\multicolumn{2}{c}{Problem if} & \\multicolumn{2}{c}{Non-severe} & \\multicolumn{2}{c}{Encourage work} \\\\",
             "& \\multicolumn{2}{c}{spends too much} & \\multicolumn{2}{c}{can work but} & \\multicolumn{2}{c}{should be} & \\multicolumn{2}{c}{if impairment} \\\\",
             "& \\multicolumn{2}{c}{on SSDI benefits} & \\multicolumn{2}{c}{is on SSDI} & \\multicolumn{2}{c}{ineligible} & \\multicolumn{2}{c}{is less severe} \\\\",
             att_out[13:14],
             "  & & & & & & & & \\\\ ",
             "  \\multicolumn{9}{c}{\\textbf{A. Among All Subjects}} \\\\ ",
             "  & & & & \\\\ ",
             att_out[15:36],
             "  & & & & & & & & \\\\ ",
             "  \\multicolumn{9}{c}{\\textbf{B. Robustness Check: Among Subjects In Both Waves }} \\\\ ",
             "  & & & & & & & & \\\\ ",
             sg_bw[c(9:30)],
             "  & & & & & & & & \\\\ ",
             "  \\multicolumn{9}{c}{\\textbf{C. Robustness Check: Among Subjects In Both Waves Who Never Received SSDI Benefits}} \\\\ ",
             "  & & & & & & & & \\\\ ",
             sg_selfn[c(9:30)],
             att_out[38:length(att_out)])

cat(att_out, file="appendix_tableA12.tex", sep="\n")
