
cces$z_ssdi_anyrp <- rep(NA, nrow(cces))
cces$z_ssdi_anyrp <- ifelse(cces$z_ssdi_rp | cces$z_ssdi_rp_lr, 1, cces$z_ssdi_anyrp)
cces$z_ssdi_anyrp <- ifelse(cces$z_ssdi_co | cces$z_ssdi_co_le | cces$z_ssdi_appeal=="Control", 0, cces$z_ssdi_anyrp)
with(cces[cces$in_post == 1,], table(z_ssdi_appeal, z_ssdi_anyrp, exclude=NULL))
with(cces[cces$in_post == 0,], table(z_ssdi_appeal, z_ssdi_anyrp, exclude=NULL))

cces$z_ssdi_anyco <- rep(NA, nrow(cces))
cces$z_ssdi_anyco <- ifelse(cces$z_ssdi_co | cces$z_ssdi_co_le, 1, cces$z_ssdi_anyco)
cces$z_ssdi_anyco <- ifelse(cces$z_ssdi_rp | cces$z_ssdi_rp_lr | cces$z_ssdi_appeal=="Control", 0, cces$z_ssdi_anyco)
with(cces[cces$in_post == 1,], table(z_ssdi_appeal, z_ssdi_anyco, exclude=NULL))
with(cces[cces$in_post == 0,], table(z_ssdi_appeal, z_ssdi_anyco, exclude=NULL))


fit_att_pool <- list()
c_means_pool <- list()
diff_rp_co_lincom <- list()
ctr<-0
for(i in 1:length(Ys)){
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco")
  fit_att_pool[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means_pool[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom[[ctr]] <- summary(glht(fit_att_pool[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att_pool[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means_pool[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom[[ctr]] <- summary(glht(fit_att_pool[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
}

lincom_out <- lapply(diff_rp_co_lincom, function(J){
  x <- c(J$test$coefficients,
         J$test$sigma,
         J$test$pvalues)
  x_fmt <- sprintf("%.3f", round(x, 3))
  x_fmt[1] <- ifelse(x[3] < 0.01, paste0("$",x_fmt[1],"^{***}$"), 
                     ifelse(x[3] < 0.05, paste0("$",x_fmt[1],"^{**}$"),
                            ifelse( x[3] < 0.1, paste0("$",x_fmt[1],"^{*}$"), x_fmt[1] )))
  x_fmt[3] <- ifelse(x[3] < 0.001, "[p<0.001]", paste0("[p=",x_fmt[3],"]" ))
  x_fmt[2] <- paste0("(", x_fmt[2], ")")
  return(x_fmt)
})

c_means_pool <- sprintf("%.3f", unlist(c_means_pool))

lincom_out <- do.call(cbind, lincom_out)
lincom_out

# stargazer(fit_att_pool[[6]],
#           fit_att_pool[[2]],
#           fit_att_pool[[1]],
#           fit_att_pool[[3]])

sgout <- stargazer(fit_att_pool[[11]], fit_att_pool[[12]], 
                   fit_att_pool[[3]], fit_att_pool[[4]], 
                   fit_att_pool[[1]], fit_att_pool[[2]], 
                   fit_att_pool[[5]], fit_att_pool[[6]],
                   keep = c("z_ssdi_anyrp", "z_ssdi_anyco", "Constant"),
                   covariate.labels = c("Any Risk Pooling Treatment", "Any Costly Program Treatment", "Constant"),
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   column.sep.width = "0pt",
                   add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                    c("Control Group Mean Outcome", c_means_pool[c(11,12,3,4,1,2,5,6)]),
                                    c("Diff: Any Risk Pooling Treatment", lincom_out[1,c(11,12,3,4,1,2,5,6)]),
                                    c("~~~Minus Any Costly Program Treatment",lincom_out[2,c(11,12,3,4,1,2,5,6)]),
                                    c("",lincom_out[3,c(11,12,3,4,1,2,5,6)])),
                   float=FALSE)


swaps_input <- as.matrix(t(c("\\textit{Note:}  & \\multicolumn{8}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", "")),
                         ncol=2, byrow=TRUE)

att_out_pool <- makeTexTable(sgout=sgout,
                             caption="Effect of any risk pooling appeal or any costly program appeal on SSDI program attitudes",
                             label="tab:attitudes_experiment_pool",
                             rsboxwidth = 1,
                             notes = c("Source: 2016 CCES team module, post-election wave",
                                       "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                       "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, party identification, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                             swaps = swaps_input)

att_out_pool <- c(att_out_pool[1:12],
                  "& \\multicolumn{8}{c}{DV = Agreement with statement } \\\\",
                  "& \\multicolumn{8}{c}{(5-pt scale, -2 strongly disagree to 2 strongly agree) } \\\\",
                  "\\cline{2-9}",
                  "& \\multicolumn{2}{c}{Federal gov} & \\multicolumn{2}{c}{Problem if} & \\multicolumn{2}{c}{Non-severe} & \\multicolumn{2}{c}{Encourage work} \\\\",
                  "& \\multicolumn{2}{c}{spends too much} & \\multicolumn{2}{c}{can work but} & \\multicolumn{2}{c}{should be} & \\multicolumn{2}{c}{if impairment} \\\\",
                  "& \\multicolumn{2}{c}{on SSDI benefits} & \\multicolumn{2}{c}{is on SSDI} & \\multicolumn{2}{c}{ineligible} & \\multicolumn{2}{c}{is less severe} \\\\",
                  att_out_pool[13:26],
                  "\\hline \\\\[-1.8ex] ",
                  att_out_pool[27:29],
                  "\\hline \\\\[-1.8ex] ",
                  att_out_pool[30:length(att_out_pool)])

cat(att_out_pool, file="appendix_tableA13.tex", sep="\n")

