# Estimate treatment effects
fit_att <- list()
c_means <- list()
ctr <- 0
for(i in 1:length(Ys)){
  
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le")
  fit_att[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1))
  c_means[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
}
c_means <- sprintf("%.3f", unlist(c_means))

# Robustness: Among those who have never previously received SSDI benefits (among those in both pre and post wave)

fit_att_selfn <- list()
c_means_selfn <- list()
ctr <- 0

for(i in 1:length(Ys)){
  
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le")
  fit_att_selfn[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1 & self_ssdi == "Has never received SSDI"))
  c_means_selfn[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$self_ssdi == "Has never received SSDI" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_rp + z_ssdi_rp_lr + z_ssdi_co + z_ssdi_co_le + age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat")
  fit_att_selfn[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & in_pre == 1 & self_ssdi == "Has never received SSDI"))
  c_means_selfn[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$in_pre == 1 & cces$self_ssdi == "Has never received SSDI" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  
}
c_means_selfn <- sprintf("%.3f", unlist(c_means_selfn))

sgout <- stargazer(fit_att[[7]], fit_att[[8]], 
                   fit_att[[9]], fit_att[[10]],
                   keep = c("z_ssdi_rp", "z_ssdi_rp_lr", "z_ssdi_co", "z_ssdi_co_le", "Constant"),
                   covariate.labels = c("Risk Pooling",
                                        "Risk Pooling + Low Abuse Risk",
                                        "Costly Program",
                                        "Costly Program + Lax Eligibility",
                                        "Constant"),
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   column.sep.width = "0pt",
                   add.lines = list(c("With Covariates?", rep(c("N", "Y"), 2)),
                                    c("Control Group Mean Outcome", c_means[7:10])),
                   float=FALSE)

sg_selfn <- stargazer(fit_att_selfn[[7]], fit_att_selfn[[8]], 
                      fit_att_selfn[[9]], fit_att_selfn[[10]], 
                      keep = c("z_ssdi_rp", "z_ssdi_rp_lr", "z_ssdi_co", "z_ssdi_co_le", "Constant"),
                      covariate.labels = c("Risk Pooling",
                                           "Risk Pooling + Low Abuse Risk",
                                           "Costly Program",
                                           "Costly Program + Lax Eligibility",
                                           "Constant"),
                      keep.stat=c("n", "adj.rsq"),
                      dep.var.caption = "",
                      dep.var.labels.include = FALSE,
                      table.placement = "!ht",
                      column.sep.width = "0pt",
                      add.lines = list(c("With Covariates?", rep(c("N", "Y"), 2)),
                                       c("Control Group Mean Outcome", c_means_selfn[7:10])),
                      float=FALSE)

swaps_input <- as.matrix(t(c("\\textit{Note:}  & \\multicolumn{4}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", "")),
                         ncol=2, byrow=TRUE)

att_out_appx <- makeTexTable(sgout=sgout,
                             caption="Effect of informational appeals about the SSDI program on other attitudes about SSDI",
                             label="tab:attitudes_experiment_appx",
                             rsboxwidth = .5,
                             notes = c("Source: 2016 CCES team module",
                                       "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                       "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, party identification, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                             swaps = swaps_input)

att_out_appx <- c(att_out_appx[1:12],
                  "& \\multicolumn{4}{c}{DV = Agreement with statement (5-pt scale;} \\\\",
                  "& \\multicolumn{4}{c}{-2 strongly disagree to 2 strongly agree) } \\\\",
                  "\\cline{2-5}",
                  "& \\multicolumn{2}{c}{} & \\multicolumn{2}{c}{Mandate employers}  \\\\",
                  "& \\multicolumn{2}{c}{Allow SSDI recipients} & \\multicolumn{2}{c}{to provide long-term}  \\\\",
                  "& \\multicolumn{2}{c}{to exceed monthly} & \\multicolumn{2}{c}{DI at least as}  \\\\",
                  "& \\multicolumn{2}{c}{income limit} & \\multicolumn{2}{c}{generous as SSDI}  \\\\",
                  att_out_appx[13:14],
                  "  & & & & \\\\ ",
                  "  \\multicolumn{5}{c}{\\textbf{A. Among All Subjects}} \\\\ ",
                  "  & & & & \\\\ ",
                  att_out_appx[15:36],
                  "  & & & & \\\\ ",
                  "  \\multicolumn{5}{c}{\\textbf{B. Robustness Check: Among Subjects}} \\\\ ",
                  "  \\multicolumn{5}{c}{\\textbf{Who Never Received SSDI Benefits}} \\\\ ",
                  "  \\multicolumn{5}{c}{\\textit{(and who were in both pre- and post-election waves)}} \\\\ ",
                  "  & & & & \\\\ ",
                  sg_selfn[c(9:30)],
                  att_out_appx[38:length(att_out_appx)])

cat(att_out_appx, file="appendix_tableA14.tex", sep="\n")