
cces$z_ssdi_anyrp <- rep(NA, nrow(cces))
cces$z_ssdi_anyrp <- ifelse(cces$z_ssdi_rp | cces$z_ssdi_rp_lr, 1, cces$z_ssdi_anyrp)
cces$z_ssdi_anyrp <- ifelse(cces$z_ssdi_co | cces$z_ssdi_co_le | cces$z_ssdi_appeal=="Control", 0, cces$z_ssdi_anyrp)
with(cces[cces$in_post == 1,], table(z_ssdi_appeal, z_ssdi_anyrp, exclude=NULL))
with(cces[cces$in_post == 0,], table(z_ssdi_appeal, z_ssdi_anyrp, exclude=NULL))

cces$z_ssdi_anyco <- rep(NA, nrow(cces))
cces$z_ssdi_anyco <- ifelse(cces$z_ssdi_co | cces$z_ssdi_co_le, 1, cces$z_ssdi_anyco)
cces$z_ssdi_anyco <- ifelse(cces$z_ssdi_rp | cces$z_ssdi_rp_lr | cces$z_ssdi_appeal=="Control", 0, cces$z_ssdi_anyco)
with(cces[cces$in_post == 1,], table(z_ssdi_appeal, z_ssdi_anyco, exclude=NULL))
with(cces[cces$in_post == 0,], table(z_ssdi_appeal, z_ssdi_anyco, exclude=NULL))

# Recode selected covariates with small cell sizes for covariate adjusted analyses
cces$rc_marstat <- rep(NA, nrow(cces))
cces$rc_marstat <- ifelse(cces$marstat %in% c("Separated", "Unknown marital status"), "Separated or Unknown", cces$marstat)
with(cces, table(marstat, rc_marstat, exclude=NULL))

cces$rc_unionhh <- rep(NA, nrow(cces))
cces$rc_unionhh <- ifelse(cces$unionhh %in% c("No, no one in my household has ever been a member of a labor union",
                                        "Unknown union household status"),
                       "No or Unknown", cces$unionhh)
with(cces, table(unionhh, rc_unionhh, exclude=NULL))

table(cces$hispanic, exclude=NULL)
cces$rc_hispanic <- rep(NA, nrow(cces))
cces$rc_hispanic <- ifelse(cces$hispanic %in% c("No", "Unknown if Hispanic"), "No or Unknown", cces$hispanic)
with(cces, table(hispanic, rc_hispanic, exclude=NULL))

### INITIALIZE OBJECTS TO STORE OUTPUT

fit_att_pool_dem <- fit_att_pool_ind <- fit_att_pool_rep <- list()
c_means_pool_dem <- c_means_pool_ind <- c_means_pool_rep <- list()
diff_rp_co_lincom_dem <- diff_rp_co_lincom_ind <- diff_rp_co_lincom_rep <- list()

### DEMOCRATS

ctr<-0
for(i in 1:length(Ys)){
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco")
  fit_att_pool_dem[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & pid3=="Democrat"))
  c_means_pool_dem[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$pid3=="Democrat" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_dem[[ctr]] <- summary(glht(fit_att_pool_dem[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco + age + gender + rc_ideo5 + votereg + educ + race + rc_hispanic + rc_marstat + employ + ownhome + union + rc_unionhh + faminc + immstat")
  fit_att_pool_dem[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & pid3=="Democrat"))
  c_means_pool_dem[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$pid3=="Democrat" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_dem[[ctr]] <- summary(glht(fit_att_pool_dem[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
}

lincom_out_dem <- lapply(diff_rp_co_lincom_dem, function(J){
  x <- c(J$test$coefficients,
         J$test$sigma,
         J$test$pvalues)
  x_fmt <- sprintf("%.3f", round(x, 3))
  x_fmt[1] <- ifelse(x[3] < 0.01, paste0("$",x_fmt[1],"^{***}$"), 
                     ifelse(x[3] < 0.05, paste0("$",x_fmt[1],"^{**}$"),
                            ifelse( x[3] < 0.1, paste0("$",x_fmt[1],"^{*}$"), x_fmt[1] )))
  x_fmt[3] <- ifelse(x[3] < 0.001, "[p<0.001]", paste0("[p=",x_fmt[3],"]" ))
  x_fmt[2] <- paste0("(", x_fmt[2], ")")
  return(x_fmt)
})

c_means_pool_dem <- sprintf("%.3f", unlist(c_means_pool_dem))
lincom_out_dem <- do.call(cbind, lincom_out_dem)

sgout_dem <- stargazer(fit_att_pool_dem[[11]], fit_att_pool_dem[[12]], 
                       fit_att_pool_dem[[3]], fit_att_pool_dem[[4]], 
                       fit_att_pool_dem[[1]], fit_att_pool_dem[[2]], 
                       fit_att_pool_dem[[5]], fit_att_pool_dem[[6]],
                       keep = c("z_ssdi_anyrp", "z_ssdi_anyco", "Constant"),
                       covariate.labels = c("Any Risk Pooling Treatment", "Any Costly Program Treatment", "Constant"),
                       keep.stat=c("n", "adj.rsq"),
                       dep.var.caption = "",
                       dep.var.labels.include = FALSE,
                       table.placement = "!ht",
                       column.sep.width = "0pt",
                       add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                        c("Control Group Mean Outcome", c_means_pool_dem[c(11,12,3,4,1,2,5,6)]),
                                        c("Diff: Any Risk Pooling Treatment", lincom_out_dem[1,c(11,12,3,4,1,2,5,6)]),
                                        c("~~~Minus Any Costly Program Treatment",lincom_out_dem[2,c(11,12,3,4,1,2,5,6)]),
                                        c("",lincom_out_dem[3,c(11,12,3,4,1,2,5,6)])),
                       float=FALSE)

### REPUBLICANS

ctr<-0
for(i in 1:length(Ys)){
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco")
  fit_att_pool_rep[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & pid3=="Republican"))
  c_means_pool_rep[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$pid3=="Republican" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_rep[[ctr]] <- summary(glht(fit_att_pool_rep[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco + age + gender + rc_ideo5 + votereg + educ + race + rc_hispanic + rc_marstat + employ + ownhome + union + rc_unionhh + faminc + immstat")
  fit_att_pool_rep[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & pid3=="Republican"))
  c_means_pool_rep[[ctr]] <- round(mean(cces[cces$in_post == 1 & cces$pid3=="Republican" & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_rep[[ctr]] <- summary(glht(fit_att_pool_rep[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
}

lincom_out_rep <- lapply(diff_rp_co_lincom_rep, function(J){
  x <- c(J$test$coefficients,
         J$test$sigma,
         J$test$pvalues)
  x_fmt <- sprintf("%.3f", round(x, 3))
  x_fmt[1] <- ifelse(x[3] < 0.01, paste0("$",x_fmt[1],"^{***}$"), 
                     ifelse(x[3] < 0.05, paste0("$",x_fmt[1],"^{**}$"),
                            ifelse( x[3] < 0.1, paste0("$",x_fmt[1],"^{*}$"), x_fmt[1] )))
  x_fmt[3] <- ifelse(x[3] < 0.001, "[p<0.001]", paste0("[p=",x_fmt[3],"]" ))
  x_fmt[2] <- paste0("(", x_fmt[2], ")")
  return(x_fmt)
})

c_means_pool_rep <- sprintf("%.3f", unlist(c_means_pool_rep))
lincom_out_rep <- do.call(cbind, lincom_out_rep)

sgout_rep <- stargazer(fit_att_pool_rep[[11]], fit_att_pool_rep[[12]], 
                       fit_att_pool_rep[[3]], fit_att_pool_rep[[4]], 
                       fit_att_pool_rep[[1]], fit_att_pool_rep[[2]], 
                       fit_att_pool_rep[[5]], fit_att_pool_rep[[6]],
                       keep = c("z_ssdi_anyrp", "z_ssdi_anyco", "Constant"),
                       covariate.labels = c("Any Risk Pooling Treatment", "Any Costly Program Treatment", "Constant"),
                       keep.stat=c("n", "adj.rsq"),
                       dep.var.caption = "",
                       dep.var.labels.include = FALSE,
                       table.placement = "!ht",
                       column.sep.width = "0pt",
                       add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                        c("Control Group Mean Outcome", c_means_pool_rep[c(11,12,3,4,1,2,5,6)]),
                                        c("Diff: Any Risk Pooling Treatment", lincom_out_rep[1,c(11,12,3,4,1,2,5,6)]),
                                        c("~~~Minus Any Costly Program Treatment",lincom_out_rep[2,c(11,12,3,4,1,2,5,6)]),
                                        c("",lincom_out_rep[3,c(11,12,3,4,1,2,5,6)])),
                       float=FALSE)

### INDEPENDENTS

ctr<-0
for(i in 1:length(Ys)){
  # Unadjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco")
  fit_att_pool_ind[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & !(pid3 %in% c("Democrat", "Republican"))))
  c_means_pool_ind[[ctr]] <- round(mean(cces[cces$in_post == 1 & !(cces$pid3 %in% c("Democrat", "Republican")) & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_ind[[ctr]] <- summary(glht(fit_att_pool_ind[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
  
  # Covariate adjusted
  ctr <- ctr + 1
  fmla <- paste0(paste0("rc_", Ys[i]), "~ z_ssdi_anyrp + z_ssdi_anyco + age + gender + rc_ideo5 + votereg + educ + race + rc_hispanic + rc_marstat + employ + ownhome + union + rc_unionhh + faminc + immstat")
  fit_att_pool_ind[[ctr]] <- lm(formula=fmla, data=cces, subset=(in_post==1 & !(pid3 %in% c("Democrat", "Republican"))))
  c_means_pool_ind[[ctr]] <- round(mean(cces[cces$in_post == 1 & !(cces$pid3 %in% c("Democrat", "Republican")) & cces$z_ssdi_appeal == "Control", paste0("rc_", Ys[i])] , na.rm=TRUE), 3)
  diff_rp_co_lincom_ind[[ctr]] <- summary(glht(fit_att_pool_ind[[ctr]], linfct = c("z_ssdi_anyrp - z_ssdi_anyco = 0")))
}

lincom_out_ind <- lapply(diff_rp_co_lincom_ind, function(J){
  x <- c(J$test$coefficients,
         J$test$sigma,
         J$test$pvalues)
  x_fmt <- sprintf("%.3f", round(x, 3))
  x_fmt[1] <- ifelse(x[3] < 0.01, paste0("$",x_fmt[1],"^{***}$"), 
                     ifelse(x[3] < 0.05, paste0("$",x_fmt[1],"^{**}$"),
                            ifelse( x[3] < 0.1, paste0("$",x_fmt[1],"^{*}$"), x_fmt[1] )))
  x_fmt[3] <- ifelse(x[3] < 0.001, "[p<0.001]", paste0("[p=",x_fmt[3],"]" ))
  x_fmt[2] <- paste0("(", x_fmt[2], ")")
  return(x_fmt)
})

c_means_pool_ind <- sprintf("%.3f", unlist(c_means_pool_ind))
lincom_out_ind <- do.call(cbind, lincom_out_ind)

sgout_ind <- stargazer(fit_att_pool_ind[[11]], fit_att_pool_ind[[12]], 
                       fit_att_pool_ind[[3]], fit_att_pool_ind[[4]], 
                       fit_att_pool_ind[[1]], fit_att_pool_ind[[2]], 
                       fit_att_pool_ind[[5]], fit_att_pool_ind[[6]],
                       keep = c("z_ssdi_anyrp", "z_ssdi_anyco", "Constant"),
                       covariate.labels = c("Any Risk Pooling Treatment", "Any Costly Program Treatment", "Constant"),
                       keep.stat=c("n", "adj.rsq"),
                       dep.var.caption = "",
                       dep.var.labels.include = FALSE,
                       table.placement = "!ht",
                       column.sep.width = "0pt",
                       add.lines = list(c("With Covariates?", rep(c("N", "Y"), 4)),
                                        c("Control Group Mean Outcome", c_means_pool_ind[c(11,12,3,4,1,2,5,6)]),
                                        c("Diff: Any Risk Pooling Treatment", lincom_out_ind[1,c(11,12,3,4,1,2,5,6)]),
                                        c("~~~Minus Any Costly Program Treatment",lincom_out_ind[2,c(11,12,3,4,1,2,5,6)]),
                                        c("",lincom_out_ind[3,c(11,12,3,4,1,2,5,6)])),
                       float=FALSE)




swaps_input <- as.matrix(t(c("\\textit{Note:}  & \\multicolumn{8}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", "")),
                         ncol=2, byrow=TRUE)

att_out_pool_dem <- makeTexTable(sgout=sgout_dem,
                                 caption="Effect of any risk pooling appeal or any costly program appeal on SSDI program attitudes, by subject's party identification",
                                 label="tab:attitudes_experiment_pool_bypid",
                                 rsboxwidth = .9,
                                 notes = c("Source: 2016 CCES team module, post-election wave",
                                           "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                           "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                                 swaps = swaps_input)

att_out_pool_ind <- makeTexTable(sgout=sgout_ind,
                                 caption="Effect of any risk pooling appeal or any costly program appeal on SSDI program attitudes, by subject's party identification",
                                 label="tab:attitudes_experiment_pool_bypid",
                                 rsboxwidth = .9,
                                 notes = c("Source: 2016 CCES team module, post-election wave",
                                           "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                           "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                                 swaps = swaps_input)

att_out_pool_rep <- makeTexTable(sgout=sgout_rep,
                                 caption="Effect of any risk pooling appeal or any costly program appeal on SSDI program attitudes, by subject's party identification",
                                 label="tab:attitudes_experiment_pool_bypid",
                                 rsboxwidth = .9,
                                 notes = c("Source: 2016 CCES team module, post-election wave",
                                           "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                           "The table reports coefficients from an ordinary least squares model regressing each outcome variable on binary treatment indicators, without and with covariates. The omitted reference category is the control group. Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                                 swaps = swaps_input)


att_out_pool_bypid <- c(att_out_pool_dem[1:12],
                        "& \\multicolumn{8}{c}{DV = Agreement with statement } \\\\",
                        "& \\multicolumn{8}{c}{(5-pt scale, -2 strongly disagree to 2 strongly agree) } \\\\",
                        "\\cline{2-9}",
                        "& \\multicolumn{2}{c}{Federal gov} & \\multicolumn{2}{c}{Problem if} & \\multicolumn{2}{c}{Non-severe} & \\multicolumn{2}{c}{Encourage work} \\\\",
                        "& \\multicolumn{2}{c}{spends too much} & \\multicolumn{2}{c}{can work but} & \\multicolumn{2}{c}{should be} & \\multicolumn{2}{c}{if impairment} \\\\",
                        "& \\multicolumn{2}{c}{on SSDI benefits} & \\multicolumn{2}{c}{is on SSDI} & \\multicolumn{2}{c}{ineligible} & \\multicolumn{2}{c}{is less severe} \\\\",
                        att_out_pool_dem[13:14],
                        att_out_pool_dem[25],
                        "\\hline \\\\[-1.8ex] ",
                        " \\multicolumn{9}{c}{\\textbf{A. Democrats}} \\\\  ",
                        att_out_pool_dem[15:23], "\\hline",
                        att_out_pool_dem[26:31],
                        "\\hline\\hline \\\\[-1.8ex] ",
                        " \\multicolumn{9}{c}{\\textbf{B. Independents}} \\\\  ",
                        att_out_pool_ind[15:23], "\\hline",
                        att_out_pool_ind[26:31],
                        "\\hline\\hline \\\\[-1.8ex] ",
                        " \\multicolumn{9}{c}{\\textbf{C. Republicans}} \\\\  ",
                        att_out_pool_rep[15:23], "\\hline",
                        att_out_pool_rep[26:31],
                        "\\hline\\hline \\\\[-1.8ex] ",
                        att_out_pool_dem[35:length(att_out_pool_dem)])

cat(att_out_pool_bypid, file="appendix_tableA15.tex", sep="\n")

