
## Regression analysis --- no sample restriction

fit_blk <- list(lm(fh_ssdi_blk   ~ pid3, data = lucid19),
                lm(fh_othpol_blk ~ pid3, data = lucid19, subset = fh_othpol_short == "TANF"),
                lm(fh_othpol_blk ~ pid3, data = lucid19, subset = fh_othpol_short == "Social Security"),
                lm(fh_othpol_blk ~ pid3, data = lucid19, subset = fh_othpol_short == "Medicaid"))

fit_wom <- list(lm(fh_ssdi_wom   ~ pid3, data = lucid19),
                lm(fh_othpol_wom ~ pid3, data = lucid19, subset = fh_othpol_short == "TANF"),
                lm(fh_othpol_wom ~ pid3, data = lucid19, subset = fh_othpol_short == "Social Security"),
                lm(fh_othpol_wom ~ pid3, data = lucid19, subset = fh_othpol_short == "Medicaid"))

fit_usb <- list(lm(fh_ssdi_usb   ~ pid3, data = lucid19),
                lm(fh_othpol_usb ~ pid3, data = lucid19, subset = fh_othpol_short == "TANF"),
                lm(fh_othpol_usb ~ pid3, data = lucid19, subset = fh_othpol_short == "Social Security"),
                lm(fh_othpol_usb ~ pid3, data = lucid19, subset = fh_othpol_short == "Medicaid"))



tab_blk <- stargazer(fit_blk,
                     covariate.labels = c("Independent", "Republican", "Constant"),
                     column.labels = c("SSDI", "TANF", "Social Security", "Medicaid"),
                     dep.var.caption = "",
                     dep.var.labels = rep("", 2),
                     keep.stat = c("n", "rsq"),
                     float = FALSE)

tab_wom <- stargazer(fit_wom,
                     covariate.labels = c("Independent", "Republican", "Constant"),
                     column.labels = c("SSDI", "TANF", "Social Security", "Medicaid"),
                     dep.var.caption = "",
                     dep.var.labels = rep("", 2),
                     keep.stat = c("n", "rsq"),
                     float = FALSE)

tab_usb <- stargazer(fit_usb,
                     covariate.labels = c("Independent", "Republican", "Constant"),
                     column.labels = c("SSDI", "TANF", "Social Security", "Medicaid"),
                     dep.var.caption = "",
                     dep.var.labels = rep("", 2),
                     keep.stat = c("n", "rsq"),
                     float = FALSE)


tab <- c("\\begin{table}[!htbp]",
         "\\centering",
         "\\caption{Partisan Differences in the Perceived Percent of Beneficiaries with a Given Trait (No Sample Restrictions)}",
         "\\label{party_diff_perceptions_unrestricted}",
         "\\resizebox{.65\\textwidth}{!}{",
         "\\begin{threeparttable}",
         tab_blk[c(4:6,8:10)],
         "  & & & & \\\\ ",
         " \\multicolumn{5}{c}{\\textbf{I. Outcome: Perceived Pct. of Beneficiaries Who Are Black/AfAm}} \\\\ ",
         "  & & & & \\\\ ",
         tab_blk[11:24],
         "  & & & & \\\\ ",
         " \\multicolumn{5}{c}{\\textbf{II. Outcome: Perceived Pct. of Beneficiaries Who Are Women}} \\\\ ",
         "  & & & & \\\\ ",
         tab_wom[11:24],
         "  & & & & \\\\ ",
         " \\multicolumn{5}{c}{\\textbf{III. Outcome: Perceived Pct. of Beneficiaries Who Are U.S. Born}} \\\\ ",
         "  & & & & \\\\ ",
         tab_usb[c(11:24, 26)],
         "\\begin{tablenotes}",
         "\\item $^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01. Cells report unadjusted OLS regression estimates with standard errors in parentheses. The omitted reference group is defined as subjects who identify as Democrats.",
         "\\end{tablenotes}",
         "\\end{threeparttable}",
         "}",
         "\\end{table}")

cat(tab, file="appendix_tableA17.tex", sep="\n")
