
names(lucid17) <- ifelse(names(lucid17) == "dem_hispanice", "dem_hispanic", names(lucid17))

demog_vars <- paste0("dem_",
                     c("pid7", "ideology", 
                       "raceblack", "raceother", "hispanic", "female", 
                       "hhincome", "education",
                       "region_ne", "region_so", "region_we", 
                       "politicalknowledge",  "interest", "registeredtovote",
                       "voted2016", "votechoice2016", "mobile"))
demog_vars <- c("agecat", demog_vars)


wtd.table(lucid17$agecat, weights= lucid17$weight)
class(lucid17)



lucid_demogs <- lapply(demog_vars, function(J){
  freq <- table(lucid17[[J]])
  prop <- table(lucid17[[J]]) / sum(table(lucid17[[J]]))
  wtd_freq <- cbind(wtd.table(x = lucid17[[J]],
                              weights = lucid17[["weight"]],
                              type = "table"))
  wtd_prop <- wtd_freq / sum(wtd_freq)
  var_name <- rownames(wtd_freq)
  x <- cbind(paste0(J, "= ", var_name), 
             freq, 
             paste0("(", sprintf("%0.2f", round(prop,2)) ,")"), 
             round(wtd_freq, 2), 
             paste0("(", sprintf("%0.2f", round(wtd_prop,2)) , ")"))
  colnames(x) <- c("variable", "unweighted n", "unweighted prop", "weighted n", "weighted prop")
  rownames(x) <- NULL
  x <- rbind(x, rep("", ncol(x)))
  return(x)
})

lucid_demogs <- do.call(rbind, lucid_demogs)

lucid_demogs <- as.data.frame(lucid_demogs, stringsAsFactors = FALSE)

lucid_demogs$variable <- gsub("agecat=", "Age:", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("70-105", "70+", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= -3", "Party ID: Strong Democrat", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= -2", "Party ID: Democrat", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= -1", "Party ID: Lean Democrat", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= 0", "Party ID: Independent", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= 1", "Party ID: Lean Republican", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= 2", "Party ID: Republican", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_pid7= 3", "Party ID: Strong Republican", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_ideology= 1", "Ideology: Very Liberal", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_ideology= 2", "Ideology: Liberal", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_ideology= 3", "Ideology: Moderate", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_ideology= 4", "Ideology: Conservative", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_ideology= 5", "Ideology: Very Conservative", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_raceblack= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_raceblack= 1", "Black", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_raceother= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_raceother= 1", "Other Race", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hispanic= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hispanic= 1", "Hispanic", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_female= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_female= 1", "Female", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 1", "Highest Education Attained: HS or less", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 2", "Highest Education Attained: 2", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 4", "Highest Education Attained: 4", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 5", "Highest Education Attained: 5", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 6", "Highest Education Attained: 6", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 7", "Highest Education Attained: 7", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_education= 8", "Highest Education Attained: PhD+", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 2", "Household Income Scale: 2", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 3", "Household Income Scale: 3", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 4", "Household Income Scale: 4", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 5", "Household Income Scale: 5", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 6", "Household Income Scale: 6", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 7", "Household Income Scale: 7", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 8", "Household Income Scale: 8", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 9", "Household Income Scale: 9", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 10", "Household Income Scale: 10", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 11", "Household Income Scale: 11", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 12", "Household Income Scale: 12", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 13", "Household Income Scale: 13", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 14", "Household Income Scale: 14", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 15", "Household Income Scale: 15", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 16", "Household Income Scale: 16", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 17", "Household Income Scale: 17", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 18", "Household Income Scale: 18", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 19", "Household Income Scale: 19", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 20", "Household Income Scale: 20", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 21", "Household Income Scale: 21", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 22", "Household Income Scale: 22", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 23", "Household Income Scale: 23", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 24", "Household Income Scale: 24", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 1", "Household Income Scale: 1 (Lowest)", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_hhincome= 25", "Household Income Scale: 25 (Refused)", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_ne= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_ne= 1", "Region: Northeast", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_so= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_so= 1", "Region: South", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_we= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_region_we= 1", "Region: West", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 0", "Political Knowledge Scale: 0 (Lowest)", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 1", "Political Knowledge Scale: 1", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 2", "Political Knowledge Scale: 2", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 3", "Political Knowledge Scale: 3", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 4", "Political Knowledge Scale: 4", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 5", "Political Knowledge Scale: 5", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_politicalknowledge= 6", "Political Knowledge Scale: 6 (Highest)", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_interest= 1", "Political Interest: Not at all", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_interest= 2", "Political Interest: Slightly", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_interest= 3", "Political Interest: Somewhat", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_interest= 4", "Political Interest: Very", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_interest= 5", "Political Interest: Extremely", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_registeredtovote= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_registeredtovote= 1", "Registered to Vote", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_voted2016= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_voted2016= 1", "Voted in 2016 General Election", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_votechoice2016= -1", "2016 Pres. Vote Choice: Voted for Clinton", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_votechoice2016= 0", "2016 Pres. Vote Choice: Did Not Vote for Clinton or Trump", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_votechoice2016= 1", "2016 Pres. Vote Choice: Voted for Trump", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_mobile= 0", "", lucid_demogs$variable, fixed=TRUE)
lucid_demogs$variable <- gsub("dem_mobile= 1", "Mobile Device User: Yes", lucid_demogs$variable, fixed=TRUE)

lucid_demogs <- lucid_demogs[!(lucid_demogs$variable == "" & lucid_demogs$`unweighted n` != ""),]

tab_a2 <- print(xtable(lucid_demogs), include.rownames=FALSE)
tab_a2 <- unlist(strsplit(tab_a2, "\n", fixed=TRUE))
cat(tab_a2, file="appendix_tableA2.tex", sep="\n")