# define DV
dv_equals <- list(c("40-60%", "60-80%", "80-100% (Most)"),
                  c("60-80%", "80-100% (Most)"),
                  c("80-100% (Most)"))
k <- c(40,60,80)
fit_pid_pcv <- list()
counter <- 0


for(i in 1:length(dv_equals)){
  
  # ols - no covs - no weights
  counter <- counter + 1
  fit_pid_pcv[[counter]] <- lm(I(cces$comp_can_but_wont_work %in% dv_equals[[i]]) ~ rc_pid3, data=cces, 
                               subset = (in_post == 1 & comp_can_but_wont_work != "Don't know"))
  
  # with weights
  counter <- counter + 1
  fit_pid_pcv[[counter]] <- lm(I(cces$comp_can_but_wont_work %in% dv_equals[[i]]) ~ rc_pid3, data=cces, weights = weight,
                               subset = (in_post == 1 & comp_can_but_wont_work != "Don't know"))
  
  # ols - with covs
  counter <- counter + 1
  fit_pid_pcv[[counter]] <- lm(I(cces$comp_can_but_wont_work %in% dv_equals[[i]]) ~ rc_pid3 +
                                 age + votereg + gender + educ + race + hispanic + marstat +
                                 employ + ownhome + union + unionhh + faminc + immstat, data=cces, 
                               subset=(in_post == 1 & comp_can_but_wont_work != "Don't know"))
  
  # with weights
  counter <- counter + 1
  fit_pid_pcv[[counter]] <- lm(I(cces$comp_can_but_wont_work %in% dv_equals[[i]]) ~ rc_pid3 +
                                 age + votereg + gender + educ + race + hispanic + marstat +
                                 employ + ownhome + union + unionhh + faminc + immstat, data=cces, weights = weight,
                               subset=(in_post == 1 & comp_can_but_wont_work != "Don't know"))
  
}

tab_pid_pcv <- stargazer(fit_pid_pcv,
                         title = "Party Identification and Perceptions of the Share of SSDI Recipients Who Can But Do Not Want To Work",
                         label = "tab:pidpcv",
                         column.labels = c("k=40", "k=40", "k=40", "k=40", 
                                           "k=60", "k=60", "k=60", "k=60", 
                                           "k=80", "k=80", "k=80", "k=80"),
                         dep.var.labels = "recipients can but don't want to work",
                         dep.var.caption = "DV: Perceives at least $k\\%$ of SSDI recipients can but do not want to work (1=Yes, 0=No)",
                         keep = c("rc_pid3Independent", "rc_pid3Republican", "Constant"),
                         covariate.labels = c("Independent", "Republican"),
                         keep.stat = c("n", "adj.rsq"),
                         add.lines = list(c("With Covariates?", "N", "N", "Y", "Y",  "N", "N", "Y", "Y",  "N", "N", "Y", "Y"),
                                          c("Weighted?", "N", "Y", "N", "Y", "N", "Y", "N", "Y", "N", "Y", "N", "Y")))

tab_pid_pcv <- c(tab_pid_pcv[4:6],
                 "\\resizebox{1\\textwidth}{!}{",
                 "\\begin{threeparttable}",
                 "\\begin{tabular}{@{\\extracolsep{5pt}}lcccc|cccc|cccc} ",
                 tab_pid_pcv[c(8:10)],
                 tab_pid_pcv[c(11,13:31, 33)],
                 "\\begin{tablenotes}",
                 "\\item $^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                 "\\item Cells report estimates from OLS models regressing a binary indicator that the respondent perceives at least $k\\%$ of SSDI recipients can but do not want to work on predictors. Standard errors are reported in parentheses. Sample restricted to respondents in 2016 CCES team module post-election wave survey who did not select ``Don't Know'' to the question about their perceptions of the percentage of SSDI recipients who are able to work but do not want to work. The omitted reference category is Democrats. Control variables included in the model specification are age, voter registration status, gender, highest education level attained, race, Hispanic, marital status, employment status, homeownership status, union member, union household, family income level, and immigration status.",
                 "\\end{tablenotes}",
                 "\\end{threeparttable}",
                 "}",
                 tab_pid_pcv[34])

cat(tab_pid_pcv, file="appendix_tableA3.tex", sep="\n")
