
grps <- c("parent", "immfam", "extfam", "friend", "cowork", "acquai", "online", "commun")

table(lucid17$know_parent, exclude=NULL)
table(lucid17$work_parent, exclude=NULL)

with(lucid17, table(know_parent, work_parent, exclude=NULL))
with(lucid17, table(know_parent, deserve_parent, exclude=NULL))
with(lucid17, table(work_parent, deserve_parent, exclude=NULL))

# Create composite variable: know SSDI recipient and perceived work ability
for(i in 1:length(grps)){
  vname <- paste0("know_work_", grps[i])
  kvar <- paste0("know_", grps[i])
  wvar <- paste0("work_", grps[i])
  lucid17[[vname]] <- rep( "Don't Know/Refused" , nrow(lucid17))
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 0 , "No", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & lucid17[[wvar]] == 1, "Yes and could have worked", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & (lucid17[[wvar]] == .5 | is.na(lucid17[[wvar]])) , "Yes and DK if could work", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & lucid17[[wvar]] == 0 , "Yes and could not have worked", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( is.na(lucid17[[vname]]) , "Don't Know/Refused", lucid17[[vname]] )
}

# Create composite variable: know SSDI recipient and perceived deservingness
for(i in 1:length(grps)){
  vname <- paste0("know_deserve_", grps[i])
  kvar <- paste0("know_", grps[i])
  dvar <- paste0("deserve_", grps[i])
  lucid17[[vname]] <- rep( "Don't Know/Refused" , nrow(lucid17))
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 0 , "No", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & lucid17[[dvar]] == 1, "Yes and deserving", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & is.na(lucid17[[dvar]]) , "Yes and DK if deserving", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( lucid17[[kvar]] == 1 & lucid17[[dvar]] == 0 , "Yes and undeserving", lucid17[[vname]])
  lucid17[[vname]] <- ifelse( is.na(lucid17[[vname]]) , "Don't Know/Refused", lucid17[[vname]] )
}

# Distribution on composite variables

# unweighted

calc_oth <- function(df, vars, weighted=FALSE, wtvar=NULL, reorder=NULL) {
  if (!weighted) {
    x <-   lapply(vars, function(J) {
      unweighted_n <- wtd.table(df[[J]], type="table")
      unweighted_p <- round(100 * unweighted_n / sum(unweighted_n), 2)
      unweighted_p <- sprintf("%0.2f", unweighted_p)
      out <- cbind(unweighted_n, unweighted_p)
      if (!is.null(reorder)) out <- out[reorder,]
      return(out)
    })
  } else {
    x <-   lapply(vars, function(J) {
      weighted_n <- round(wtd.table(df[[J]], df[[wtvar]], type="table"), 3)
      weighted_p <- round(100 * weighted_n / sum(weighted_n), 2)
      weighted_n <- sprintf("%0.2f", weighted_n)
      weighted_p <- sprintf("%0.2f", weighted_p)
      out <- cbind(weighted_n, weighted_p)
      if (!is.null(reorder)) out <- out[reorder,]
      return(out)
    })
  }
  return(x)
}

# calculate

know_work_un <- calc_oth(df=lucid17, vars=paste0("know_work_",grps), reorder=c(2,4,3,5,1))
know_work_wt <- calc_oth(df=lucid17, vars=paste0("know_work_",grps), weighted=TRUE, wtvar="weight", reorder=c(2,4,3,5,1))

know_desrv_un <- calc_oth(df=lucid17, vars=paste0("know_deserve_",grps), reorder=c(2:4,1))
know_desrv_wt <- calc_oth(df=lucid17, vars=paste0("know_deserve_",grps), weighted=TRUE, wtvar="weight", reorder=c(2:4,1))

# function for ratios

calc_ratios <- function(x, r1, r2) {
  out <- lapply(x, function(J){
    as.numeric(J[r1,1]) / sum(as.numeric(J[r2,1]))
  })
  
  out <- unlist(out)
  return(out)
}

know_work_un_ratio_main <- calc_ratios(x = know_work_un, r1 = 2, r2 = 3)
know_work_un_ratio_alt1 <- calc_ratios(x = know_work_un, r1 = 2, r2 = 3:4)
know_work_un_ratio_alt2 <- calc_ratios(x = know_work_un, r1 = 2, r2 = 3:5)

know_work_wt_ratio_main <- calc_ratios(x = know_work_wt, r1 = 2, r2 = 3)
know_work_wt_ratio_alt1 <- calc_ratios(x = know_work_wt, r1 = 2, r2 = 3:4)
know_work_wt_ratio_alt2 <- calc_ratios(x = know_work_wt, r1 = 2, r2 = 3:5)

know_desrv_un_ratio_main <- calc_ratios(x = know_desrv_un, r1 = 2, r2 = 3)
know_desrv_un_ratio_alt1 <- calc_ratios(x = know_desrv_un, r1 = 2, r2 = 3:4)

know_desrv_wt_ratio_main <- calc_ratios(x = know_desrv_wt, r1 = 2, r2 = 3)
know_desrv_wt_ratio_alt1 <- calc_ratios(x = know_desrv_wt, r1 = 2, r2 = 3:4)


# Assemble table

TAB_know_work_un <- do.call(cbind, know_work_un)
TAB_know_work_wt <- do.call(cbind, know_work_wt)

TAB_know_desrv_un <- do.call(cbind, know_desrv_un)
TAB_know_desrv_wt <- do.call(cbind, know_desrv_wt)





### MAKE TABLE A4 ###

# Make table panel: Know deserve - Unweighted

know_desrv_un_ratios <- list(know_desrv_un_ratio_main,
                             know_desrv_un_ratio_alt1)
know_desrv_un_ratios <- lapply(know_desrv_un_ratios, function(J){
  J <- sprintf("%0.2f", round(J, 2))
  K <- c()
  for(k in 1:length(J)) K <- c(K, J[k], "")
  return(K)
})
know_desrv_un_ratios <- do.call(rbind, know_desrv_un_ratios)
rownames(know_desrv_un_ratios) <- c("Ratio: Row 2 to Row 3", 
                                    "Alt. Ratio: Row 2 to Sum of Rows 3-4")


TAB_desrv_un <- rbind(TAB_know_desrv_un, know_desrv_un_ratios)
tab_a4_panelA <- print(xtable(TAB_desrv_un))
tab_a4_panelA <- unlist(strsplit(tab_a4_panelA, "\n", fixed=TRUE))
cat(tab_a4_panelA, file="appendix_tableA4_panelA.tex", sep="\n")

# Make table panel: Know deserve - Weighted

know_desrv_wt_ratios <- list(know_desrv_wt_ratio_main,
                             know_desrv_wt_ratio_alt1)
know_desrv_wt_ratios <- lapply(know_desrv_wt_ratios, function(J){
  J <- sprintf("%0.2f", round(J, 2))
  K <- c()
  for(k in 1:length(J)) K <- c(K, J[k], "")
  return(K)
})
know_desrv_wt_ratios <- do.call(rbind, know_desrv_wt_ratios)
rownames(know_desrv_wt_ratios) <- c("Ratio: Row 2 to Row 3", 
                                    "Alt. Ratio: Row 2 to Sum of Rows 3-4")

rownames(TAB_know_desrv_wt) <- rownames(TAB_know_desrv_un)

TAB_desrv_wt <- rbind(TAB_know_desrv_wt, know_desrv_wt_ratios)


tab_a4_panelB <- print(xtable(TAB_desrv_wt))
tab_a4_panelB <- unlist(strsplit(tab_a4_panelB, "\n", fixed=TRUE))
cat(tab_a4_panelB, file="appendix_tableA4_panelB.tex", sep="\n")



### MAKE TABLE A5 ###

# Make table panel: Know work - Unweighted

know_work_un_ratios <- list(know_work_un_ratio_main,
                            know_work_un_ratio_alt1,
                            know_work_un_ratio_alt2)
know_work_un_ratios <- lapply(know_work_un_ratios, function(J){
  J <- round(J, 2)
  K <- c()
  for(k in 1:length(J)) K <- c(K, J[k], "")
  return(K)
})
know_work_un_ratios <- do.call(rbind, know_work_un_ratios)
rownames(know_work_un_ratios) <- c("Ratio: Row 2 to Row 3", 
                                   "Alt. Ratio: Row 2 to Sum of Rows 3-4",
                                   "Alt. Ratio: Row 2 to Sum of Rows 3-5")


TAB_work_un <- rbind(TAB_know_work_un, know_work_un_ratios)
tab_a5_panelA <- print(xtable(TAB_work_un))
tab_a5_panelA <- unlist(strsplit(tab_a5_panelA, "\n", fixed=TRUE))
cat(tab_a5_panelA, file="appendix_tableA5_panelA.tex", sep="\n")


# Make table panel: Know work - Weighted

know_work_wt_ratios <- list(know_work_wt_ratio_main,
                            know_work_wt_ratio_alt1,
                            know_work_wt_ratio_alt2)
know_work_wt_ratios <- lapply(know_work_wt_ratios, function(J){
  J <- round(J, 2)
  K <- c()
  for(k in 1:length(J)) K <- c(K, J[k], "")
  return(K)
})
know_work_wt_ratios <- do.call(rbind, know_work_wt_ratios)
rownames(know_work_wt_ratios) <- c("Ratio: Row 2 to Row 3", 
                                   "Alt. Ratio: Row 2 to Sum of Rows 3-4",
                                   "Alt. Ratio: Row 2 to Sum of Rows 3-5")
rownames(TAB_know_work_wt) <- rownames(TAB_know_work_un)

TAB_work_wt <- rbind(TAB_know_work_wt, know_work_wt_ratios)
tab_a5_panelB <- print(xtable(TAB_work_wt))
tab_a5_panelB <- unlist(strsplit(tab_a5_panelB, "\n", fixed=TRUE))
cat(tab_a5_panelB, file="appendix_tableA5_panelB.tex", sep="\n")

