

calc_mean_95ci <- function(df, x, digits=NULL, prop=FALSE, weighted=FALSE, wtvar=NULL) {
  
  if(is.null(digits)) digits <- 2
  
  
  if(!weighted){
    est_mean <- mean(df[[x]], na.rm=TRUE)
    est_sd <- sd(df[[x]], na.rm=TRUE)
    est_n <- sum(!is.na(df[[x]]))
    est_se <- est_sd / sqrt(est_n)
    
    if (prop) {
      est_se <- sqrt( (est_mean * (1 - est_mean)) / est_n )
    }
    
  } else {
    est_mean <- wtd.mean(x=df[[x]], weights=df[[wtvar]])
    est_sd <- sqrt(wtd.var(x=df[[x]], weights=df[[wtvar]]))
    est_n <- sum( df[[wtvar]][!is.na(df[[x]])]  )
    est_se <- est_sd / sqrt(est_n)
    
    if (prop) {
      est_se <- sqrt( (est_mean * (1 - est_mean)) / est_n )
    }
  }
  
  est_lci <- est_mean - qt( 1-(0.05/2) , est_n-1) * est_se
  est_uci <- est_mean + qt( 1-(0.05/2) , est_n-1) * est_se 
  
  est_mean <- sprintf(  paste0("%.",digits,"f")  , round(est_mean, digits))
  
  est_lci <- sprintf(  paste0("%.",digits,"f")  , round(est_lci, digits))
  est_uci <- sprintf(  paste0("%.",digits,"f")  , round(est_uci, digits))
  
  est_cis <- paste0("[", est_lci, ", ", est_uci, "]")
  
  out <- c(est_mean, est_cis, est_n)
  names(out) <- c("Estimate", "95% CI", "N")
  return(out)  
}





agg_stats <- rbind(cbind("Proportion of respondents who believe the average SSDI recipient deserves benefits", 
                         t(calc_mean_95ci(df=lucid17, x="av_deserve", prop=TRUE)),
                         t(calc_mean_95ci(df=lucid17, x="av_deserve", prop=TRUE, weighted=TRUE, wtvar="weight"))),
                   cbind("Mean respondent belief about whether the average SSDI recipient could work", 
                         t(calc_mean_95ci(df=lucid17, x="av_work")),
                         t(calc_mean_95ci(df=lucid17, x="av_work", weighted=TRUE, wtvar="weight"))),
                   cbind("Mean estimate: Number out of 100 people receiving SSDI who could have worked", 
                         t(calc_mean_95ci(df=lucid17, x="couldwork100")),
                         t(calc_mean_95ci(df=lucid17, x="couldwork100", weighted=TRUE, wtvar="weight"))
                   ))



tab_a6 <- agg_stats[,c(1,2,3,5,6,4)]

tab_a6 <- print(xtable(tab_a6), include.rownames=FALSE)
tab_a6 <- unlist(strsplit(tab_a6, "\n", fixed=TRUE))

cat(tab_a6, file="appendix_tableA6.tex", sep="\n")