
fit1 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1))
fit2 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & pid3 == "Democrat"))
fit3 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & !(pid3 %in% c("Democrat", "Republican"))))
fit4 <- lm(deserve ~ -1 + z_injuredjob + z_stroke + z_mood + z_heartfail + z_arthritis,
           data=cces, subset=(in_pre == 1 & pid3 == "Republican"))

# Calculate difference between Dem and Rep
diff_demrep_injured <- with(cces[cces$in_pre == 1,], 
                            t.test(x=deserve[z_injuredjob == 1 & pid3 == "Democrat"], 
                                   y=deserve[z_injuredjob == 1 & pid3 == "Republican"],
                                   alternative="two.sided",
                                   conf.level=0.95))

diff_demrep_stroke <- with(cces[cces$in_pre == 1,], 
                           t.test(x=deserve[z_stroke == 1 & pid3 == "Democrat"], 
                                  y=deserve[z_stroke == 1 & pid3 == "Republican"],
                                  alternative="two.sided",
                                  conf.level=0.95))

diff_demrep_mood <- with(cces[cces$in_pre == 1,], 
                         t.test(x=deserve[z_mood == 1 & pid3 == "Democrat"], 
                                y=deserve[z_mood == 1 & pid3 == "Republican"],
                                alternative="two.sided",
                                conf.level=0.95))

diff_demrep_heartfail <- with(cces[cces$in_pre == 1,], 
                              t.test(x=deserve[z_heartfail == 1 & pid3 == "Democrat"], 
                                     y=deserve[z_heartfail == 1 & pid3 == "Republican"],
                                     alternative="two.sided",
                                     conf.level=0.95))

diff_demrep_arthritis <- with(cces[cces$in_pre == 1,], 
                              t.test(x=deserve[z_arthritis == 1 & pid3 == "Democrat"], 
                                     y=deserve[z_arthritis == 1 & pid3 == "Republican"],
                                     alternative="two.sided",
                                     conf.level=0.95))

diff_out <- function(x) {
  diff_est <- sprintf("%.3f", round(unlist(x$estimate[[1]] - x$estimate[[2]]), 3))
  
  if ( round(unlist(x$p.value),3) < 0.001 ){
    diff_p <- "[p<0.001]"
  } else {
    diff_p <- paste0("[p=",round(unlist(x$p.value),3),"]")
  }
  
  out<-c(diff_est, diff_p)
  names(out) <- NULL
  return(out)
}

diff_demrep_injured <- diff_out(x=diff_demrep_injured)
diff_demrep_stroke<- diff_out(x=diff_demrep_stroke)
diff_demrep_mood<- diff_out(x=diff_demrep_mood)
diff_demrep_heartfail<- diff_out(x=diff_demrep_heartfail)
diff_demrep_arthritis<- diff_out(x=diff_demrep_arthritis)

# Mean agreement - by treatment (pooled); and by partisanship

sgout <- stargazer(fit1, fit2, fit3, fit4,
                   title="Mean Agreement Score by Treatment Arm (-2=Strongly Disagree, 2=Strongly Agree): Agrees the government should grant SSDI benefits to hypothetical recipient with given medical impairment", 
                   covariate.labels=c("Injured on the job", "Intellectual disability due to stroke", "Mood disorder", "Chronic heart failure", "Severe arthritis of the spine"),
                   column.labels=c("All Subjects", "Dems", "Inds", "Reps"),
                   column.sep.width = "0pt",
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   float=FALSE)

swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}}lcccc} ", "\\begin{tabular}{@{\\extracolsep{0pt}}p{3in}ccccc} "),
                     c("\\textit{Note:}  & \\multicolumn{4}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", ""),
                     c("\\\\[-1.8ex] & (1) & (2) & (3) & (4)\\\\ ", "\\\\[-1.8ex] & (1) & (2) & (3) & (4) & (5)\\\\ "),
                     c(" & All Subjects & Dems & Inds & Reps \\\\ ",
                       " & All Subjects & Dems & Inds & Reps & Diff (D-R) \\\\ "),
                     c(sgout[10],
                       paste0(" Injured on the job & 0.686$^{***}$ & 0.785$^{***}$ & 0.812$^{***}$ & 0.375$^{***}$ &",diff_demrep_injured[1],"\\\\ ")),
                     c(sgout[11],
                       paste0("  & (0.069) & (0.110) & (0.115) & (0.132) &",diff_demrep_injured[2],"\\\\ ")),
                     c(sgout[13],
                       paste0(" Intellectual disability due to stroke & 1.032$^{***}$ & 1.161$^{***}$ & 1.057$^{***}$ & 0.814$^{***}$ &",diff_demrep_stroke[1],"\\\\ ")),
                     c(sgout[14],
                       paste0("  & (0.073) & (0.113) & (0.127) & (0.137) &",diff_demrep_stroke[2],"\\\\ ")),
                     c(sgout[16],
                       paste0(" Mood disorder & $-$0.031 & 0.346$^{***}$ & $-$0.059 & $-$0.476$^{***}$ &",diff_demrep_mood[1],"\\\\ ")),
                     c(sgout[17],
                       paste0("  & (0.071) & (0.118) & (0.115) & (0.133) &",diff_demrep_mood[2],"\\\\ ")),
                     c(sgout[19],
                       paste0(" Chronic heart failure & 0.835$^{***}$ & 1.052$^{***}$ & 0.621$^{***}$ & 0.787$^{***}$ &",diff_demrep_heartfail[1],"\\\\ ")),
                     c(sgout[20],
                       paste0("  & (0.071) & (0.107) & (0.113) & (0.154) &",diff_demrep_heartfail[2],"\\\\ ")),
                     c(sgout[22],
                       paste0(" Severe arthritis of the spine & 0.846$^{***}$ & 0.882$^{***}$ & 0.747$^{***}$ & 0.937$^{***}$ &",diff_demrep_arthritis[1],"\\\\ ")),
                     c(sgout[23],
                       paste0("  & (0.071) & (0.121) & (0.113) & (0.132) &",diff_demrep_arthritis[2],"\\\\ ")),
                     c("  & & & & \\\\ ", "  & & & & & \\\\ "),
                     c(sgout[26], "Observations & 1,145 & 434 & 414 & 297 & \\\\ "),
                     c(sgout[27], "Adjusted R$^{2}$ & 0.335 & 0.415 & 0.313 & 0.301 & \\\\ "))

mean_agree_tab1 <- makeTexTable(sgout=sgout,
                                caption="Mean agreement with government decision to grant SSDI benefits to recipient, by the medical impairment of the SSDI benefit recipient and by the subject's (perceiver's) party identification.",
                                label="tab:mean_agree_byparty",
                                rsboxwidth = .85,
                                notes = c("Source: 2016 CCES team module, pre-election wave",
                                          "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                          "The outcome variable is the subject's agreement with the government's decision to grant SSDI benefits to a hypothetical recipient with a given medical impairment, and is measured using a 5-point scale (-2=Strongly Disagree, 2=Strongly Agree). The table reports coefficients from an ordinary least squares model regressing the agreement score on binary treatment indicators and no intercept. Standard errors are shown in parentheses; two-tailed $p$-values are shown in brackets."),
                                swaps = swaps_input)

mean_agree_tab1 <- c(mean_agree_tab1[1:12],
                     "& & \\multicolumn{3}{c}{By Subject's Party ID} & \\\\",
                     "\\cline{3-5}",
                     mean_agree_tab1[13:length(mean_agree_tab1)])

cat(mean_agree_tab1, file="appendix_tableA8.tex", sep="\n")

