
# Effect of impairment on agreement score

fit1i <- lm(deserve ~ z_injuredjob + z_stroke + z_heartfail + z_arthritis,
            data=cces, subset=(in_pre == 1))
summary(fit1i)

fit1i_cov <- lm(deserve ~ z_injuredjob + z_stroke + z_heartfail + z_arthritis +
                  age + gender + rc_pid3 + rc_ideo5 + votereg + educ + race + hispanic + marstat + employ + ownhome + union + unionhh + faminc + immstat,
                data=cces, subset=(in_pre == 1))
summary(fit1i_cov)

sgout <- stargazer(fit1i, fit1i_cov,
                   title="Mean Agreement Score by Treatment Arm (-2=Strongly Disagree, 2=Strongly Agree): Agrees the government should grant SSDI benefits to hypothetical recipient with given medical impairment", 
                   keep = c("z_injuredjob", "z_stroke", "z_heartfail", "z_arthritis", "Constant"),
                   covariate.labels=c("Injured on the job", "Intellectual disability due to stroke", "Chronic heart failure", "Severe arthritis of the spine", "Constant"),
                   column.labels=c("Unadjusted", "Covariate adjusted"),
                   column.sep.width = "0pt",
                   keep.stat=c("n", "adj.rsq"),
                   dep.var.caption = "",
                   dep.var.labels.include = FALSE,
                   table.placement = "!ht",
                   add.lines = list(c("With Covariates?", "N", "Y"),
                                    c("Mean Outcome in Comparison Group (Mood Disorder):", "-0.031", "-0.031")),
                   float=FALSE)

swaps_input <- rbind(c("\\begin{tabular}{@{\\extracolsep{0pt}}lcc} ", "\\begin{tabular}{@{\\extracolsep{0pt}}p{5in}cc} "),
                     c("\\textit{Note:}  & \\multicolumn{2}{r}{$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01} \\\\ ", ""))


impairfxtab <- makeTexTable(sgout=sgout,
                            caption="Effect of alternative easier-to-diagnose impairments (as compared to having a mood disorder, a harder-to-diagnose impairment) on agreement with government decision to grant SSDI benefits to recipient with a given impairment.",
                            label="tab:impairmentfx",
                            rsboxwidth = .8,
                            notes = c("Source: 2016 CCES team module, pre-election wave",
                                      "$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                                      "The outcome variable is the subject's agreement with the government's decision to grant SSDI benefits to a hypothetical recipient with a given medical impairment, and is measured using a 5-point scale (-2=Strongly Disagree, 2=Strongly Agree). The table reports coefficients from an ordinary least squares model regressing the agreement score on binary treatment indicators (omitting the mood disorder condition as the reference group). Standard errors are shown in parentheses. Pre-treatment covariates included in the covariate adjusted model include age, gender, party identification, ideology, voter registration status, education, race, Hispanic origin, marital status, employment status, home ownership status, union member status, union member household status, family income level, and immigrant status."),
                            swaps = swaps_input)

cat(impairfxtab, file="appendix_tableA9.tex", sep="\n")
